@@ -471,6 +471,7 @@ int main(int argc,char **argv)
                   if (i == argc)
                     MagickError(OptionError,"Missing color",option);
                   (void) CloneString(&resource_info.background_color,argv[i]);
+                  (void) CloneString(&image_info->background_color,argv[i]);
                 }
               break;
             }
@@ -1409,7 +1410,7 @@ int main(int argc,char **argv)
                 (void) WriteImage(image_info,image);
               }
             if (image_info->verbose)
-              DescribeImage(image,stderr,False);
+              DescribeImage(image,stdout,False);
             /*
               Proceed to next/previous image.
             */
