@@ -180,8 +180,12 @@ static Image *XMagickCommand(Display *display,XResourceInfo *resource_info,
         (void) strcpy(local_info->filename,filelist[i]);
         *local_info->magick='\0';
         next_image=ReadImage(local_info);
+#if 0
+        /* Something's wrong here.  No matching AllocMemory except for
+           filelist[0] .. glennrp Jun 1999 */
         if (filelist[i] != filenames)
           FreeMemory((char *) filelist[i]);
+#endif
         if (next_image != (Image *) NULL)
           {
             if (image == (Image *) NULL)
@@ -198,6 +202,9 @@ static Image *XMagickCommand(Display *display,XResourceInfo *resource_info,
         (void) SetMonitorHandler(handler);
         ProgressMonitor(LoadImageText,i,number_files);
       }
+#if 1
+      FreeMemory(filelist[0]);
+#endif
       DestroyImageInfo(local_info);
       if (image == (Image *) NULL)
         {
@@ -528,7 +535,8 @@ Export void XAnimateBackgroundImage(Display *display,
   */
   if (window_info.id == root_window)
     XDestroyWindowColors(display,root_window);
-  CoalesceImages(image);
+  if (image->next != (Image *)NULL)
+    CoalesceImages(image);
   if (resources.map_type == (char *) NULL)
     if ((visual_info->class != TrueColor) &&
         (visual_info->class != DirectColor))
@@ -1097,7 +1105,8 @@ Export Image *XAnimateImages(Display *display,XResourceInfo *resource_info,
   class_hints=windows->class_hints;
   manager_hints=windows->manager_hints;
   root_window=XRootWindow(display,visual_info->screen);
-  CoalesceImages(image);
+  if (image->next != (Image *)NULL)
+    CoalesceImages(image);
   if (resource_info->map_type == (char *) NULL)
     if ((visual_info->class != TrueColor) &&
         (visual_info->class != DirectColor))
@@ -1869,14 +1878,35 @@ Export Image *XAnimateImages(Display *display,XResourceInfo *resource_info,
             /*
               Display image named by the Drag-and-Drop selection.
             */
-            if ((int) (*event.xclient.data.l) != 2)
+            if (((int) (*event.xclient.data.l) != 2) &&
+                ((int) (*event.xclient.data.l) != 128))
               break;
             selection=XInternAtom(display,"DndSelection",False);
             status=XGetWindowProperty(display,root_window,selection,0L,2047L,
               False,(Atom) AnyPropertyType,&type,&format,&length,&after,&data);
             if ((status != Success) || (length == 0))
               break;
-            (void) strcpy(resource_info->image_info->filename,(char *) data);
+            if ((int) (*event.xclient.data.l) == 2)
+              {
+                /*
+                  Offix DND.
+                */
+                (void) strcpy(resource_info->image_info->filename,
+                  (char *) data);
+              }
+            else
+              {
+                /*
+                  XDND.
+                */
+                if (strncmp((char *) data, "file:", 5) != 0)
+                  {
+                    XFree((void *) data);
+                    break;
+                  }
+                (void) strcpy(resource_info->image_info->filename,
+                  ((char *) data)+5);
+              }
             loaded_image=ReadImage(resource_info->image_info);
             if (loaded_image != (Image *) NULL)
               state|=ExitState;
