@@ -215,22 +215,22 @@ Export void AnnotateImage(Image *image,const AnnotateInfo *annotate_info)
       }
       case NorthGravity:
       {
-        local_info->bounds.x=x+(width >> 1)-(annotate_image->columns >> 1);
-        local_info->bounds.y=y+i*local_info->bounds.height;
+        local_info->bounds.x=(width >> 1)-(annotate_image->columns >> 1)+x;
+        local_info->bounds.y=i*local_info->bounds.height+y;
         break;
       }
       case NorthEastGravity:
       {
-        local_info->bounds.x=x+width-annotate_image->columns;
-        local_info->bounds.y=y+i*local_info->bounds.height;
+        local_info->bounds.x=width-annotate_image->columns+x;
+        local_info->bounds.y=i*local_info->bounds.height+y;
         break;
       }
       case WestGravity:
       {
         local_info->bounds.x=x;
-        local_info->bounds.y=y+(height >> 1)-
+        local_info->bounds.y=(height >> 1)-
           (number_lines*local_info->bounds.height >> 1)+
-          i*local_info->bounds.height;
+          i*local_info->bounds.height+y;
         break;
       }
       case ForgetGravity:
@@ -238,36 +238,36 @@ Export void AnnotateImage(Image *image,const AnnotateInfo *annotate_info)
       case CenterGravity:
       default:
       {
-        local_info->bounds.x=x+(width >> 1)-(annotate_image->columns >> 1);
-        local_info->bounds.y=y+(height >> 1)-
+        local_info->bounds.x=(width >> 1)-(annotate_image->columns >> 1)+x;
+        local_info->bounds.y=(height >> 1)-
           (number_lines*local_info->bounds.height >> 1)+
-          i*local_info->bounds.height;
+          i*local_info->bounds.height+y;
         break;
       }
       case EastGravity:
       {
-        local_info->bounds.x=x+width-annotate_image->columns;
-        local_info->bounds.y=y+(height >> 1)-
+        local_info->bounds.x=width-annotate_image->columns-x;
+        local_info->bounds.y=(height >> 1)-
           (number_lines*local_info->bounds.height >> 1)+
-          i*local_info->bounds.height;
+          i*local_info->bounds.height-y;
         break;
       }
       case SouthWestGravity:
       {
         local_info->bounds.x=x;
-        local_info->bounds.y=y+height-(i+1)*local_info->bounds.height;
+        local_info->bounds.y=height-(i+1)*local_info->bounds.height-y;
         break;
       }
       case SouthGravity:
       {
-        local_info->bounds.x=x+(width >> 1)-(annotate_image->columns >> 1);
-        local_info->bounds.y=y+height-(i+1)*local_info->bounds.height;
+        local_info->bounds.x=(width >> 1)-(annotate_image->columns >> 1)-x;
+        local_info->bounds.y=height-(i+1)*local_info->bounds.height-y;
         break;
       }
       case SouthEastGravity:
       {
-        local_info->bounds.x=x+width-annotate_image->columns;
-        local_info->bounds.y=y+height-(i+1)*local_info->bounds.height;
+        local_info->bounds.x=width-annotate_image->columns-x;
+        local_info->bounds.y=height-(i+1)*local_info->bounds.height-y;
         break;
       }
     }
