@@ -106,7 +106,8 @@ Export Image *ReadCMYKImage(const ImageInfo *image_info)
     *scanline;
 
   unsigned int
-    packet_size;
+    packet_size,
+    status;
 
   unsigned short
     value;
@@ -124,11 +125,11 @@ Export Image *ReadCMYKImage(const ImageInfo *image_info)
       /*
         Open image file.
       */
-      OpenImage(image_info,image,ReadBinaryType);
-      if (image->file == (FILE *) NULL)
+      status=OpenBlob(image_info,image,ReadBinaryType);
+      if (status == False)
         ReaderExit(FileOpenWarning,"Unable to open file",image);
       for (i=0; i < image->offset; i++)
-        (void) fgetc(image->file);
+        (void) ReadByte(image);
     }
   /*
     Allocate memory for a scanline.
@@ -146,8 +147,8 @@ Export Image *ReadCMYKImage(const ImageInfo *image_info)
       */
       image->scene++;
       for (y=0; y < (int) image->rows; i++)
-        (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-          image->file);
+        (void) ReadBlob(image,packet_size*image->tile_info.width,
+          (char *) scanline);
     }
   do
   {
@@ -173,14 +174,14 @@ Export Image *ReadCMYKImage(const ImageInfo *image_info)
           No interlacing:  CMYKCMYKCMYKCMYKCMYK...
         */
         for (y=0; y < image->tile_info.y; y++)
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
         q=image->pixels;
         for (y=0; y < (int) image->rows; y++)
         {
           if ((y > 0) || (image->previous == (Image *) NULL))
-            (void) ReadData((char *) scanline,packet_size,
-              image->tile_info.width,image->file);
+            (void) ReadBlob(image,packet_size*image->tile_info.width,
+              (char *) scanline);
           p=scanline+packet_size*image->tile_info.x;
           for (x=0; x < (int) image->columns; x++)
           {
@@ -197,8 +198,8 @@ Export Image *ReadCMYKImage(const ImageInfo *image_info)
         }
         count=image->tile_info.height-image->rows-image->tile_info.y;
         for (y=0; y < count; y++)
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
         break;
       }
       case LineInterlace:
@@ -208,13 +209,13 @@ Export Image *ReadCMYKImage(const ImageInfo *image_info)
         */
         packet_size=image->depth >> 3;
         for (y=0; y < image->tile_info.y; y++)
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
         for (y=0; y < (int) image->rows; y++)
         {
           if ((y > 0) || (image->previous == (Image *) NULL))
-            (void) ReadData((char *) scanline,packet_size,
-              image->tile_info.width,image->file);
+            (void) ReadBlob(image,packet_size*image->tile_info.width,
+              (char *) scanline);
           p=scanline+packet_size*image->tile_info.x;
           q=image->pixels+y*image->columns;
           for (x=0; x < (int) image->columns; x++)
@@ -223,8 +224,8 @@ Export Image *ReadCMYKImage(const ImageInfo *image_info)
             q->length=0;
             q++;
           }
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
           p=scanline+packet_size*image->tile_info.x;
           q=image->pixels+y*image->columns;
           for (x=0; x < (int) image->columns; x++)
@@ -232,8 +233,8 @@ Export Image *ReadCMYKImage(const ImageInfo *image_info)
             ReadQuantum(q->green,p);
             q++;
           }
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
           p=scanline+packet_size*image->tile_info.x;
           q=image->pixels+y*image->columns;
           for (x=0; x < (int) image->columns; x++)
@@ -241,8 +242,8 @@ Export Image *ReadCMYKImage(const ImageInfo *image_info)
             ReadQuantum(q->blue,p);
             q++;
           }
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
           p=scanline+packet_size*image->tile_info.x;
           q=image->pixels+y*image->columns;
           for (x=0; x < (int) image->columns; x++)
@@ -256,8 +257,8 @@ Export Image *ReadCMYKImage(const ImageInfo *image_info)
         }
         count=image->tile_info.height-image->rows-image->tile_info.y;
         for (y=0; y < count; y++)
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
         break;
       }
       case PlaneInterlace:
@@ -269,21 +270,21 @@ Export Image *ReadCMYKImage(const ImageInfo *image_info)
         if (image_info->interlace == PartitionInterlace)
           {
             AppendImageFormat("C",image->filename);
-            OpenImage(image_info,image,ReadBinaryType);
-            if (image->file == (FILE *) NULL)
+            status=OpenBlob(image_info,image,ReadBinaryType);
+            if (status == False)
               ReaderExit(FileOpenWarning,"Unable to open file",image);
           }
         packet_size=image->depth >> 3;
         for (y=0; y < image->tile_info.y; y++)
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
         i=0;
         q=image->pixels;
         for (y=0; y < (int) image->rows; y++)
         {
           if ((y > 0) || (image->previous == (Image *) NULL))
-            (void) ReadData((char *) scanline,packet_size,
-              image->tile_info.width,image->file);
+            (void) ReadBlob(image,packet_size*image->tile_info.width,
+              (char *) scanline);
           p=scanline+packet_size*image->tile_info.x;
           for (x=0; x < (int) image->columns; x++)
           {
@@ -298,24 +299,24 @@ Export Image *ReadCMYKImage(const ImageInfo *image_info)
         }
         count=image->tile_info.height-image->rows-image->tile_info.y;
         for (y=0; y < count; y++)
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
         if (image_info->interlace == PartitionInterlace)
           {
-            CloseImage(image);
+            CloseBlob(image);
             AppendImageFormat("M",image->filename);
-            OpenImage(image_info,image,ReadBinaryType);
-            if (image->file == (FILE *) NULL)
+            status=OpenBlob(image_info,image,ReadBinaryType);
+            if (status == False)
               ReaderExit(FileOpenWarning,"Unable to open file",image);
           }
         q=image->pixels;
         for (y=0; y < image->tile_info.y; y++)
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
         for (y=0; y < (int) image->rows; y++)
         {
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
           p=scanline+packet_size*image->tile_info.x;
           for (x=0; x < (int) image->columns; x++)
           {
@@ -329,24 +330,24 @@ Export Image *ReadCMYKImage(const ImageInfo *image_info)
         }
         count=image->tile_info.height-image->rows-image->tile_info.y;
         for (y=0; y < count; y++)
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
         if (image_info->interlace == PartitionInterlace)
           {
-            CloseImage(image);
+            CloseBlob(image);
             AppendImageFormat("Y",image->filename);
-            OpenImage(image_info,image,ReadBinaryType);
-            if (image->file == (FILE *) NULL)
+            status=OpenBlob(image_info,image,ReadBinaryType);
+            if (status == False)
               ReaderExit(FileOpenWarning,"Unable to open file",image);
           }
         q=image->pixels;
         for (y=0; y < image->tile_info.y; y++)
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
         for (y=0; y < (int) image->rows; y++)
         {
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
           p=scanline+packet_size*image->tile_info.x;
           for (x=0; x < (int) image->columns; x++)
           {
@@ -360,24 +361,24 @@ Export Image *ReadCMYKImage(const ImageInfo *image_info)
         }
         count=image->tile_info.height-image->rows-image->tile_info.y;
         for (y=0; y < count; y++)
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
         if (image_info->interlace == PartitionInterlace)
           {
-            CloseImage(image);
+            CloseBlob(image);
             AppendImageFormat("K",image->filename);
-            OpenImage(image_info,image,ReadBinaryType);
-            if (image->file == (FILE *) NULL)
+            status=OpenBlob(image_info,image,ReadBinaryType);
+            if (status == False)
               ReaderExit(FileOpenWarning,"Unable to open file",image);
           }
         q=image->pixels;
         for (y=0; y < image->tile_info.y; y++)
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
         for (y=0; y < (int) image->rows; y++)
         {
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
           p=scanline+packet_size*image->tile_info.x;
           for (x=0; x < (int) image->columns; x++)
           {
@@ -391,15 +392,15 @@ Export Image *ReadCMYKImage(const ImageInfo *image_info)
         }
         count=image->tile_info.height-image->rows-image->tile_info.y;
         for (y=0; y < count; y++)
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
         if (image_info->interlace == PartitionInterlace)
           (void) strcpy(image->filename,image_info->filename);
         break;
       }
     }
     CondenseImage(image);
-    if (feof(image->file))
+    if (EOFBlob(image))
       MagickWarning(CorruptImageWarning,"not enough pixels",image->filename);
     if (image_info->subrange != 0)
       if (image->scene >= (image_info->subimage+image_info->subrange-1))
@@ -407,8 +408,7 @@ Export Image *ReadCMYKImage(const ImageInfo *image_info)
     /*
       Proceed to next image.
     */
-    count=ReadData((char *) scanline,packet_size,image->columns,
-      image->file);
+    count=ReadBlob(image,packet_size*image->columns,(char *) scanline);
     if (count > 0)
       {
         /*
@@ -421,14 +421,14 @@ Export Image *ReadCMYKImage(const ImageInfo *image_info)
             return((Image *) NULL);
           }
         image=image->next;
-        ProgressMonitor(LoadImagesText,(unsigned int) ftell(image->file),
+        ProgressMonitor(LoadImagesText,(unsigned int) TellBlob(image),
           (unsigned int) image->filesize);
       }
   } while (count > 0);
   FreeMemory((char *) scanline);
   while (image->previous != (Image *) NULL)
     image=image->previous;
-  CloseImage(image);
+  CloseBlob(image);
   return(image);
 }
 
@@ -476,7 +476,8 @@ Export unsigned int WriteCMYKImage(const ImageInfo *image_info,Image *image)
     *p;
 
   unsigned int
-    scene;
+    scene,
+    status;
 
   image->depth=QuantumDepth;
   if (image_info->interlace != PartitionInterlace)
@@ -484,8 +485,8 @@ Export unsigned int WriteCMYKImage(const ImageInfo *image_info,Image *image)
       /*
         Open output image file.
       */
-      OpenImage(image_info,image,WriteBinaryType);
-      if (image->file == (FILE *) NULL)
+      status=OpenBlob(image_info,image,WriteBinaryType);
+      if (status == False)
         WriterExit(FileOpenWarning,"Unable to open file",image);
     }
   scene=0;
@@ -535,7 +536,7 @@ Export unsigned int WriteCMYKImage(const ImageInfo *image_info,Image *image)
             x++;
             if (x == (int) image->columns)
               {
-                (void) fwrite((char *) pixels,1,q-pixels,image->file);
+                (void) WriteBlob(image,q-pixels,(char *) pixels);
                 if (image->previous == (Image *) NULL)
                   if (QuantumTick(y,image->rows))
                     ProgressMonitor(SaveImageText,y,image->rows);
@@ -596,8 +597,8 @@ Export unsigned int WriteCMYKImage(const ImageInfo *image_info,Image *image)
         if (image_info->interlace == PartitionInterlace)
           {
             AppendImageFormat("C",image->filename);
-            OpenImage(image_info,image,WriteBinaryType);
-            if (image->file == (FILE *) NULL)
+            status=OpenBlob(image_info,image,WriteBinaryType);
+            if (status == False)
               WriterExit(FileOpenWarning,"Unable to open file",image);
           }
         p=image->pixels;
@@ -609,10 +610,10 @@ Export unsigned int WriteCMYKImage(const ImageInfo *image_info,Image *image)
         }
         if (image_info->interlace == PartitionInterlace)
           {
-            CloseImage(image);
+            CloseBlob(image);
             AppendImageFormat("M",image->filename);
-            OpenImage(image_info,image,WriteBinaryType);
-            if (image->file == (FILE *) NULL)
+            status=OpenBlob(image_info,image,WriteBinaryType);
+            if (status == False)
               WriterExit(FileOpenWarning,"Unable to open file",image);
           }
         ProgressMonitor(SaveImageText,100,400);
@@ -625,10 +626,10 @@ Export unsigned int WriteCMYKImage(const ImageInfo *image_info,Image *image)
         }
         if (image_info->interlace == PartitionInterlace)
           {
-            CloseImage(image);
+            CloseBlob(image);
             AppendImageFormat("Y",image->filename);
-            OpenImage(image_info,image,WriteBinaryType);
-            if (image->file == (FILE *) NULL)
+            status=OpenBlob(image_info,image,WriteBinaryType);
+            if (status == False)
               WriterExit(FileOpenWarning,"Unable to open file",image);
           }
         ProgressMonitor(SaveImageText,200,400);
@@ -643,10 +644,10 @@ Export unsigned int WriteCMYKImage(const ImageInfo *image_info,Image *image)
         p=image->pixels;
         if (image_info->interlace == PartitionInterlace)
           {
-            CloseImage(image);
+            CloseBlob(image);
             AppendImageFormat("K",image->filename);
-            OpenImage(image_info,image,WriteBinaryType);
-            if (image->file == (FILE *) NULL)
+            status=OpenBlob(image_info,image,WriteBinaryType);
+            if (status == False)
               WriterExit(FileOpenWarning,"Unable to open file",image);
           }
         for (i=0; i < (int) image->packets; i++)
@@ -670,6 +671,6 @@ Export unsigned int WriteCMYKImage(const ImageInfo *image_info,Image *image)
   if (image_info->adjoin)
     while (image->previous != (Image *) NULL)
       image=image->previous;
-  CloseImage(image);
+  CloseBlob(image);
   return(True);
 }
