@@ -886,6 +886,115 @@ static void
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   C o m p r e s s C o l o r m a p                                           %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  Method CompressColormap compresses an image colormap removing any
+%  duplicate and unused color entries.
+%
+%  The format of the CompressColormap routine is:
+%
+%      CompressColormap(image)
+%
+%  A description of each parameter follows:
+%
+%    o image: The address of a structure of type Image.
+%
+%
+*/
+Export void CompressColormap(Image *image)
+{
+  ColorPacket
+    *colormap;
+
+  int
+    number_colors;
+
+  register int
+    i,
+    j;
+
+  register RunlengthPacket
+    *p;
+
+  register unsigned short
+    index;
+
+  /*
+    Determine if colormap can be compressed.
+  */
+  assert(image != (Image *) NULL);
+  if (image->class != PseudoClass)
+    return;
+  number_colors=image->colors;
+  for (i=0; i < (int) image->colors; i++)
+    image->colormap[i].flags=False;
+  image->colors=0;
+  p=image->pixels;
+  for (i=0; i < (int) image->packets; i++)
+  {
+    if (!image->colormap[p->index].flags)
+      {
+        /*
+          Eliminate duplicate colors.
+        */
+        for (j=0; j < number_colors; j++)
+          if ((j != p->index) && image->colormap[j].flags)
+            if (ColorMatch(image->colormap[p->index],image->colormap[j],0))
+              break;
+        if (j != number_colors)
+          image->colormap[p->index].index=image->colormap[j].index;
+        else
+          image->colormap[p->index].index=image->colors++;
+        image->colormap[p->index].flags=True;
+      }
+    p++;
+  }
+  if ((int) image->colors == number_colors)
+    return;  /* no duplicate or unused entries */
+  /*
+    Compress colormap.
+  */
+  colormap=(ColorPacket *) AllocateMemory(image->colors*sizeof(ColorPacket));
+  if (colormap == (ColorPacket *) NULL)
+    {
+      MagickWarning(ResourceLimitWarning,"Unable to compress colormap",
+        "Memory allocation failed");
+      image->colors=number_colors;
+      return;
+    }
+  /*
+    Eliminate unused colormap entries.
+  */
+  for (i=0; i < number_colors; i++)
+    if (image->colormap[i].flags)
+      {
+        index=image->colormap[i].index;
+        colormap[index].red=image->colormap[i].red;
+        colormap[index].green=image->colormap[i].green;
+        colormap[index].blue=image->colormap[i].blue;
+      }
+  /*
+    Remap pixels.
+  */
+  p=image->pixels;
+  for (i=0; i < (int) image->packets; i++)
+  {
+    p->index=image->colormap[p->index].index;
+    p++;
+  }
+  FreeMemory((char *) image->colormap);
+  image->colormap=colormap;
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 +  D e s t r o y L i s t                                                      %
 %                                                                             %
 %                                                                             %
@@ -1135,6 +1244,7 @@ static void Histogram(CubeInfo *color_cube,const NodeInfo *node_info,FILE *file)
         (void) QueryColorName(p,name);
         (void) fprintf(file,"%.1024s",name);
         (void) fprintf(file,"\n");
+        p++;
       }
       if (QuantumTick(color_cube->progress,color_cube->colors))
         ProgressMonitor(HistogramImageText,color_cube->progress,
@@ -1207,6 +1317,56 @@ static NodeInfo *InitializeNode(CubeInfo *color_cube,const unsigned int level)
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
 %                                                                             %
+%   I s M o n o c h r o m e I m a g e                                         %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  Method IsMonochromeImage returns True if the image is monochrome otherwise
+%  False is returned.  If the image is DirectClass and monochrome, it is
+%  demoted to PseudoClass.
+%
+%  The format of the IsMonochromeImage routine is:
+%
+%      status=IsMonochromeImage(image)
+%
+%  A description of each parameter follows:
+%
+%    o status: Method IsMonochromeImage returns True if the image is
+%      monochrome otherwise False is returned.
+%
+%    o image: The address of a structure of type Image;  returned from
+%      ReadImage.
+%
+%
+*/
+Export unsigned int IsMonochromeImage(Image *image)
+{
+  /*
+    Determine if image is monochrome.
+  */
+  assert(image != (Image *) NULL);
+  if (image->pixels == (RunlengthPacket *) NULL)
+    return(False);
+  if (!IsGrayImage(image))
+    return(False);
+  if (image->colors > 2)
+    return(False);
+  if ((Intensity(image->colormap[0]) != 0) &&
+      (Intensity(image->colormap[0]) != MaxRGB))
+    return(False);
+  if (image->colors == 2)
+    if ((Intensity(image->colormap[1]) != 0) &&
+        (Intensity(image->colormap[1]) != MaxRGB))
+      return(False);
+  return(True);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
 %                                                                             %
 %  I s P s e u d o C l a s s                                                  %
 %                                                                             %
