@@ -204,10 +204,10 @@ Export void ColorFloodfillImage(Image *image,const RunlengthPacket *target,
       Pop segment off stack.
     */
     p--;
-    x1=p->x1;
-    x2=p->x2;
-    offset=p->y2;
-    y=p->y1+offset;
+    x1=(int) p->x1;
+    x2=(int) p->x2;
+    offset=(int) p->y2;
+    y=(int) p->y1+offset;
     /*
       Recolor neighboring pixels.
     */
@@ -564,13 +564,13 @@ Export void DrawImage(Image *image,const AnnotateInfo *annotate_info)
       point.x=0;
       point.y=0;
       n=0;
-      (void) sscanf(p,"%f%f%n",&point.x,&point.y,&n);
+      (void) sscanf(p,"%lf%lf%n",&point.x,&point.y,&n);
       if (n == 0)
-        (void) sscanf(p,"%f,%f%n",&point.x,&point.y,&n);
+        (void) sscanf(p,"%lf,%lf%n",&point.x,&point.y,&n);
       if (n == 0)
-        (void) sscanf(p,"%f, %f%n",&point.x,&point.y,&n);
+        (void) sscanf(p,"%lf, %lf%n",&point.x,&point.y,&n);
       if (n == 0)
-        (void) sscanf(p,"%f %f%n",&point.x,&point.y,&n);
+        (void) sscanf(p,"%lf %lf%n",&point.x,&point.y,&n);
       if (n == 0)
         {
           MagickWarning(OptionWarning,
@@ -1503,10 +1503,10 @@ Export void MatteFloodfillImage(Image *image,const RunlengthPacket *target,
       Pop segment off stack.
     */
     p--;
-    x1=p->x1;
-    x2=p->x2;
-    offset=p->y2;
-    y=p->y1+offset;
+    x1=(int) p->x1;
+    x2=(int) p->x2;
+    offset=(int) p->y2;
+    y=(int) p->y1+offset;
     /*
       Recolor neighboring pixels.
     */
