@@ -103,7 +103,7 @@ Export Image *ReadFPXImage(const ImageInfo *image_info)
     *flashpix;
 
   FPXStatus
-    status;
+    fpx_status;
 
   FPXSummaryInformation
     summary_info;
@@ -139,11 +139,11 @@ Export Image *ReadFPXImage(const ImageInfo *image_info)
     *scanline;
 
   unsigned int
+    status,
     subimage;
 
   unsigned long
     height,
-    max_packets,
     memory_limit,
     tile_width,
     tile_height,
@@ -161,8 +161,8 @@ Export Image *ReadFPXImage(const ImageInfo *image_info)
   /*
     Open image.
   */
-  OpenImage(image_info,image,ReadBinaryType);
-  if (image->file == (FILE *) NULL)
+  status=OpenBlob(image_info,image,ReadBinaryType);
+  if (status == False)
     ReaderExit(FileOpenWarning,"Unable to open file",image);
   if ((image->file == stdin) || image->pipe)
     {
@@ -179,23 +179,23 @@ Export Image *ReadFPXImage(const ImageInfo *image_info)
       file=fopen(image_info->filename,WriteBinaryType);
       if (file == (FILE *) NULL)
         ReaderExit(FileOpenWarning,"Unable to write file",image);
-      c=fgetc(image->file);
+      c=ReadByte(image);
       while (c != EOF)
       {
         (void) putc(c,file);
-        c=fgetc(image->file);
+        c=ReadByte(image);
       }
       (void) fclose(file);
       (void) strcpy(image->filename,image_info->filename);
       image->temporary=True;
     }
-  CloseImage(image);
+  CloseBlob(image);
   /*
     Initialize FPX toolkit.
   */
   memory_limit=20000000;
-  status=FPX_SetToolkitMemoryLimit(&memory_limit);
-  if (status != FPX_OK)
+  fpx_status=FPX_SetToolkitMemoryLimit(&memory_limit);
+  if (fpx_status != FPX_OK)
     ReaderExit(DelegateWarning,"Unable to initialize FPX library",image);
   tile_width=64;
   tile_height=64;
@@ -206,18 +206,18 @@ Export Image *ReadFPXImage(const ImageInfo *image_info)
       fsspec;
 
     FilenameToFSSpec(image->filename,&fsspec);
-    status=FPX_OpenImageByFilename((const FSSpec &) fsspec,
+    fpx_status=FPX_OpenImageByFilename((const FSSpec &) fsspec,
 #else
-    status=FPX_OpenImageByFilename(image->filename,
+    fpx_status=FPX_OpenImageByFilename(image->filename,
 #endif
       NULL,&width,&height,&tile_width,&tile_height,&colorspace,&flashpix);
   }
-  if (status == FPX_LOW_MEMORY_ERROR)
+  if (fpx_status == FPX_LOW_MEMORY_ERROR)
     {
       FPX_ClearSystem();
       ReaderExit(ResourceLimitWarning,"Memory allocation failed",image);
     }
-  if (status != FPX_OK)
+  if (fpx_status != FPX_OK)
     {
       FPX_ClearSystem();
       ReaderExit(FileOpenWarning,"Unable to open FPX file",image);
@@ -231,15 +231,15 @@ Export Image *ReadFPXImage(const ImageInfo *image_info)
         Get the aspect ratio.
       */
       aspect_ratio=(float) width/height;
-      status=FPX_GetImageResultAspectRatio(flashpix,&aspect_ratio);
-      if (status != FPX_OK)
+      fpx_status=FPX_GetImageResultAspectRatio(flashpix,&aspect_ratio);
+      if (fpx_status != FPX_OK)
         MagickWarning(DelegateWarning,"Unable to read aspect ratio",
           image_info->filename);
       if (width != (unsigned long) ((aspect_ratio*height)+0.5))
         Swap(width,height);
     }
-  status=FPX_GetSummaryInformation(flashpix,&summary_info);
-  if (status != FPX_OK)
+  fpx_status=FPX_GetSummaryInformation(flashpix,&summary_info);
+  if (fpx_status != FPX_OK)
     {
       FPX_ClearSystem();
       ReaderExit(FileOpenWarning,"Unable to read summary info",image);
@@ -332,18 +332,17 @@ Export Image *ReadFPXImage(const ImageInfo *image_info)
     }
   if (image_info->ping)
     {
-      CloseImage(image);
+      CloseBlob(image);
       return(image);
     }
   /*
     Allocate memory for the image and pixel buffer.
   */
   packets=0;
-  max_packets=Max((image->columns*image->rows+2) >> 2,1);
-  image->pixels=(RunlengthPacket *)
-    AllocateMemory(max_packets*sizeof(RunlengthPacket));
   scanline=(unsigned char *) AllocateMemory(colorspace.numberOfComponents*
     image->columns*(tile_height+1)*sizeof(unsigned char));
+  image->pixels=(RunlengthPacket *)
+    AllocateMemory(image->columns*image->rows*sizeof(RunlengthPacket));
   if ((image->pixels == (RunlengthPacket *) NULL) ||
       (scanline == (unsigned char *) NULL))
     {
@@ -394,14 +393,14 @@ Export Image *ReadFPXImage(const ImageInfo *image_info)
           Read FPX image tile (with or without viewing transform)..
         */
         if (image_info->view != (char *) NULL)
-          status=FPX_ReadImageRectangle(flashpix,0,y,image->columns,y+
+          fpx_status=FPX_ReadImageRectangle(flashpix,0,y,image->columns,y+
             tile_height-1,subimage,&fpx_info);
         else
-          status=FPX_ReadImageTransformRectangle(flashpix,0.0F,(float) y/
+          fpx_status=FPX_ReadImageTransformRectangle(flashpix,0.0F,(float) y/
             image->rows,(float) image->columns/image->rows,(float) (y+
             tile_height-1)/image->rows,(long) image->columns,(long) tile_height,
             &fpx_info);
-        if (status == FPX_LOW_MEMORY_ERROR)
+        if (fpx_status == FPX_LOW_MEMORY_ERROR)
           {
             FreeMemory((char *) scanline);
             (void) FPX_CloseImage(flashpix);
@@ -442,21 +441,6 @@ Export Image *ReadFPXImage(const ImageInfo *image_info)
           if (packets != 0)
             q++;
           packets++;
-          if (packets == (int) max_packets)
-            {
-              max_packets<<=1;
-              image->pixels=(RunlengthPacket *) ReallocateMemory((char *)
-                image->pixels,max_packets*sizeof(RunlengthPacket));
-              if (image->pixels == (RunlengthPacket *) NULL)
-                {
-                  FreeMemory((char *) scanline);
-                  (void) FPX_CloseImage(flashpix);
-                  FPX_ClearSystem();
-                  ReaderExit(ResourceLimitWarning,"Memory allocation failed",
-                    image);
-                }
-              q=image->pixels+packets-1;
-            }
           q->red=red;
           q->green=green;
           q->blue=blue;
@@ -508,11 +492,11 @@ Export Image *ReadFPXImage(const ImageInfo *image_info)
 %
 %  The format of the WriteFPXImage routine is:
 %
-%      status=WriteFPXImage(image_info,image)
+%      fpx_status=WriteFPXImage(image_info,image)
 %
 %  A description of each parameter follows.
 %
-%    o status: Method WriteFPXImage return True if the image is written.
+%    o fpx_status: Method WriteFPXImage return True if the image is written.
 %      False is returned is there is a memory shortage or if the image file
 %      fails to write.
 %
@@ -729,7 +713,7 @@ Export unsigned int WriteFPXImage(const ImageInfo *image_info,Image *image)
     *flashpix;
 
   FPXStatus
-    status;
+    fpx_status;
 
   FPXSummaryInformation
     summary_info;
@@ -754,6 +738,9 @@ Export unsigned int WriteFPXImage(const ImageInfo *image_info,Image *image)
   unsigned char
     *pixels;
 
+  unsigned int
+    status;
+
   unsigned long
     memory_limit,
     tile_height,
@@ -765,8 +752,8 @@ Export unsigned int WriteFPXImage(const ImageInfo *image_info,Image *image)
   /*
     Open input file.
   */
-  OpenImage(image_info,image,WriteBinaryType);
-  if (image->file == (FILE *) NULL)
+  status=OpenBlob(image_info,image,WriteBinaryType);
+  if (status == False)
     WriterExit(FileOpenWarning,"Unable to open file",image);
   if ((image->file != stdout) && !image->pipe)
     (void) remove(image->filename);
@@ -779,14 +766,14 @@ Export unsigned int WriteFPXImage(const ImageInfo *image_info,Image *image)
       TemporaryFilename(image->filename);
       image->temporary=True;
     }
-  CloseImage(image);
+  CloseBlob(image);
   TransformRGBImage(image,RGBColorspace);
   /*
     Initialize FPX toolkit.
   */
   memory_limit=20000000;
-  status=FPX_SetToolkitMemoryLimit(&memory_limit);
-  if (status != FPX_OK)
+  fpx_status=FPX_SetToolkitMemoryLimit(&memory_limit);
+  if (fpx_status != FPX_OK)
     WriterExit(ResourceLimitWarning,"Unable to initialize FPX library",
       image);
   tile_width=64;
@@ -812,23 +799,23 @@ Export unsigned int WriteFPXImage(const ImageInfo *image_info,Image *image)
       fsspec;
 
     FilenameToFSSpec(image->filename,&fsspec);
-    status=FPX_CreateImageByFilename((const FSSpec &) fsspec,
+    fpx_status=FPX_CreateImageByFilename((const FSSpec &) fsspec,
 #else
-    status=FPX_CreateImageByFilename(image->filename,
+    fpx_status=FPX_CreateImageByFilename(image->filename,
 #endif
     image->columns,image->rows,tile_width,tile_height,colorspace,
     background_color,compression,&flashpix);
   }
-  if (status != FPX_OK)
+  if (fpx_status != FPX_OK)
     WriterExit(FileOpenWarning,"Unable to open file",image);
   if (image_info->compression == JPEGCompression)
     {
       /*
         Initialize the compression by quality for the entire image.
       */
-      status=
+      fpx_status=
         FPX_SetJPEGCompression(flashpix,(unsigned short) (image_info->quality));
-      if (status != FPX_OK)
+      if (fpx_status != FPX_OK)
         MagickWarning(DelegateWarning,"Unable to set JPEG level",(char *) NULL);
     }
   /*
@@ -880,8 +867,8 @@ Export unsigned int WriteFPXImage(const ImageInfo *image_info,Image *image)
         MagickWarning(DelegateWarning,"Unable to set image comments",
           (char *) NULL);
     }
-  status=FPX_SetSummaryInformation(flashpix,&summary_info);
-  if (status != FPX_OK)
+  fpx_status=FPX_SetSummaryInformation(flashpix,&summary_info);
+  if (fpx_status != FPX_OK)
     MagickWarning(DelegateWarning,"Unable to set summary info",(char *) NULL);
   /*
     Allocate pixels.
@@ -938,8 +925,8 @@ Export unsigned int WriteFPXImage(const ImageInfo *image_info,Image *image)
       x++;
       if (x == (int) image->columns)
         {
-          status=FPX_WriteImageLine(flashpix,&fpx_info);
-          if (status != FPX_OK)
+          fpx_status=FPX_WriteImageLine(flashpix,&fpx_info);
+          if (fpx_status != FPX_OK)
             break;
           if (QuantumTick(y,image->rows))
             ProgressMonitor(SaveImageText,y,image->rows);
@@ -1038,43 +1025,43 @@ Export unsigned int WriteFPXImage(const ImageInfo *image_info,Image *image)
         }
       if (affine_valid)
         {
-          status=FPX_SetImageAffineMatrix(flashpix,&affine);
-          if (status != FPX_OK)
+          fpx_status=FPX_SetImageAffineMatrix(flashpix,&affine);
+          if (fpx_status != FPX_OK)
             MagickWarning(DelegateWarning,"Unable to set affine matrix",
               (char *) NULL);
         }
       if (aspect_ratio_valid)
         {
-          status=FPX_SetImageResultAspectRatio(flashpix,&aspect_ratio);
-          if (status != FPX_OK)
+          fpx_status=FPX_SetImageResultAspectRatio(flashpix,&aspect_ratio);
+          if (fpx_status != FPX_OK)
             MagickWarning(DelegateWarning,"Unable to set aspect ratio",
               (char *) NULL);
         }
       if (color_twist_valid)
         {
-          status=FPX_SetImageColorTwistMatrix(flashpix,&color_twist);
-          if (status != FPX_OK)
+          fpx_status=FPX_SetImageColorTwistMatrix(flashpix,&color_twist);
+          if (fpx_status != FPX_OK)
             MagickWarning(DelegateWarning,"Unable to set color color twist",
               (char *) NULL);
         }
       if (contrast_valid)
         {
-          status=FPX_SetImageContrastAdjustment(flashpix,&contrast);
-          if (status != FPX_OK)
+          fpx_status=FPX_SetImageContrastAdjustment(flashpix,&contrast);
+          if (fpx_status != FPX_OK)
             MagickWarning(DelegateWarning,"Unable to set contrast",
               (char *) NULL);
         }
       if (sharpen_valid)
         {
-          status=FPX_SetImageFilteringValue(flashpix,&sharpen);
-          if (status != FPX_OK)
+          fpx_status=FPX_SetImageFilteringValue(flashpix,&sharpen);
+          if (fpx_status != FPX_OK)
             MagickWarning(DelegateWarning,"Unable to set filtering value",
               (char *) NULL);
         }
       if (view_rect_valid)
         {
-          status=FPX_SetImageROI(flashpix, &view_rect);
-          if (status != FPX_OK)
+          fpx_status=FPX_SetImageROI(flashpix, &view_rect);
+          if (fpx_status != FPX_OK)
             MagickWarning(DelegateWarning,"Unable to set region of interest",
               (char *) NULL);
         }
@@ -1101,7 +1088,7 @@ Export unsigned int WriteFPXImage(const ImageInfo *image_info,Image *image)
       (void) fclose(file);
       (void) remove(image->filename);
       image->temporary=False;
-      CloseImage(&fpx_image);
+      CloseBlob(&fpx_image);
     }
   return(True);
 }
