@@ -135,10 +135,10 @@ Export Image *ReadHDFImage(const ImageInfo *image_info)
   /*
     Open image file.
   */
-  OpenImage(image_info,image,ReadBinaryType);
-  if (image->file == (FILE *) NULL)
+  status=OpenBlob(image_info,image,ReadBinaryType);
+  if (status == False)
     ReaderExit(FileOpenWarning,"Unable to open file",image);
-  CloseImage(image);
+  CloseBlob(image);
   /*
     Read HDF image.
   */
@@ -164,7 +164,7 @@ Export Image *ReadHDFImage(const ImageInfo *image_info)
       image->colors=256;
     if (image_info->ping)
       {
-        CloseImage(image);
+        CloseBlob(image);
         return(image);
       }
     image->packets=image->columns*image->rows;
@@ -312,7 +312,7 @@ Export Image *ReadHDFImage(const ImageInfo *image_info)
             return((Image *) NULL);
           }
         image=image->next;
-        ProgressMonitor(LoadImagesText,(unsigned int) ftell(image->file),
+        ProgressMonitor(LoadImagesText,(unsigned int) TellBlob(image),
           (unsigned int) image->filesize);
       }
   } while (status != -1);
@@ -389,10 +389,10 @@ Export unsigned int WriteHDFImage(const ImageInfo *image_info,Image *image)
   /*
     Open output image file.
   */
-  OpenImage(image_info,image,WriteBinaryType);
-  if (image->file == (FILE *) NULL)
+  status=OpenBlob(image_info,image,WriteBinaryType);
+  if (status == False)
     WriterExit(FileOpenWarning,"Unable to open file",image);
-  CloseImage(image);
+  CloseBlob(image);
   scene=0;
   do
   {
