@@ -50,6 +50,18 @@ typedef unsigned char Quantum;
 /*
   Typedef declarations.
 */
+typedef struct _BlobInfo
+{
+  char
+    *data;
+
+  long
+    offset,
+    length,
+    extent,
+    quantum;
+} BlobInfo;
+
 typedef struct _ColorlistInfo
 {
   char
@@ -112,6 +124,11 @@ typedef struct _FrameInfo
 
 typedef struct _ImageInfo
 {
+  /*
+    Blob member.
+  */
+  BlobInfo
+    blob;
   /*
     File and image dimension members.
   */
@@ -245,7 +262,7 @@ typedef struct _MontageInfo
 
 typedef struct _PointInfo
 {
-  float
+  double
     x,
     y,
     z;
@@ -259,7 +276,7 @@ typedef struct _PrimitiveInfo
   unsigned int
     coordinates;
 
-  float
+  double
     x,
     y;
 
@@ -295,7 +312,7 @@ typedef struct _RunlengthPacket
 
 typedef struct _SegmentInfo
 {
-  float
+  double
     x1,
     y1,
     x2,
@@ -322,6 +339,9 @@ typedef struct _ChromaticityInfo
 
 typedef struct _Image
 {
+  BlobInfo
+    blob;
+
   FILE
     *file;
 
@@ -394,7 +414,7 @@ typedef struct _Image
   RenderingIntent
     rendering_intent;
 
-  float
+  double
     gamma;
 
   ChromaticityInfo
@@ -407,7 +427,7 @@ typedef struct _Image
   ResolutionType
     units;
 
-  float
+  double
     x_resolution,
     y_resolution;
 
@@ -415,8 +435,7 @@ typedef struct _Image
     *signature;
 
   RunlengthPacket
-    *pixels,
-    *packet;
+    *pixels;
 
   unsigned long
     packets;
@@ -508,6 +527,31 @@ typedef struct _AnnotateInfo
   RectangleInfo
     bounds;
 } AnnotateInfo;
+
+typedef struct _MagickInfo
+{
+  const char
+    *tag;
+
+  Image
+    *(*decoder)(const ImageInfo *);
+
+  unsigned int
+    (*encoder)(const ImageInfo *,Image *),
+    (*magick)(const unsigned char *,const unsigned int),
+    adjoin,
+    blob_support;
+
+  const char
+    *description;
+
+  void
+    *data;
+
+  struct _MagickInfo
+    *previous,
+    *next;
+} MagickInfo;
 
 /*
   Image const declarations.
@@ -612,6 +656,7 @@ extern Export Image
   *ReadRGBImage(const ImageInfo *image_info),
   *ReadRLAImage(const ImageInfo *image_info),
   *ReadRLEImage(const ImageInfo *image_info),
+  *ReadSCTImage(const ImageInfo *image_info),
   *ReadSFWImage(const ImageInfo *image_info),
   *ReadSGIImage(const ImageInfo *image_info),
   *ReadSTEGANOImage(const ImageInfo *image_info),
@@ -659,6 +704,13 @@ extern Export int
   ParseGeometry(const char *,int *,int *,unsigned int *,unsigned int *),
   ParseImageGeometry(const char *,int *,int *,unsigned int *,unsigned int *);
 
+extern Export MagickInfo
+  *GetMagickInfo(const char *),
+  *RegisterMagickInfo(const char *,Image *(*)(const ImageInfo *),
+    unsigned int (*)(const ImageInfo *,Image *),
+    unsigned int (*)(const unsigned char *,const unsigned int),
+    const unsigned int,const unsigned int,const char *);
+
 extern Export unsigned int
   AnimateImages(const ImageInfo *image_info,Image *image),
   DisplayImages(const ImageInfo *image_info,Image *image),
@@ -705,6 +757,7 @@ extern Export unsigned int
   WritePNMImage(const ImageInfo *image_info,Image *image),
   WritePREVIEWImage(const ImageInfo *image_info,Image *image),
   WritePS2Image(const ImageInfo *image_info,Image *image),
+  WritePS3Image(const ImageInfo *image_info,Image *image),
   WritePSDImage(const ImageInfo *image_info,Image *image),
   WritePSImage(const ImageInfo *image_info,Image *image),
   WriteRGBImage(const ImageInfo *image_info,Image *image),
@@ -726,7 +779,6 @@ extern Export unsigned int
 extern Export void
   AllocateNextImage(const ImageInfo *,Image *),
   AnnotateImage(Image *,const AnnotateInfo *),
-  CloseImage(Image *),
   CoalesceImages(Image *),
   ColorFloodfillImage(Image *,const RunlengthPacket *,Image *,const int x,
     const int y,const PaintMethod),
@@ -737,6 +789,7 @@ extern Export void
   CondenseImage(Image *),
   ContrastImage(Image *,const unsigned int),
   CycleColormapImage(Image *,const int),
+  DeconstructImages(Image *),
   DescribeImage(Image *,FILE *,const unsigned int),
   DestroyAnnotateInfo(AnnotateInfo *),
   DestroyImage(Image *),
@@ -752,6 +805,7 @@ extern Export void
   GetPixels(const Image *,float *,float *,float *,float *),
   LabelImage(Image *,const char *),
   LayerImage(Image *,const LayerType),
+  ListMagickInfo(FILE *),
   MatteFloodfillImage(Image *,const RunlengthPacket *,const unsigned int,
     const int x,const int y,const PaintMethod),
   MatteImage(Image *),
@@ -761,7 +815,6 @@ extern Export void
   NegateImage(Image *,const unsigned int),
   NormalizeImage(Image *),
   OpaqueImage(Image *,const char *,const char *),
-  OpenImage(const ImageInfo *,Image *,const char *),
   RaiseImage(Image *,const RectangleInfo *,const int),
   RGBTransformImage(Image *,const ColorspaceType),
   SetImage(Image *),
