@@ -1070,17 +1070,17 @@ Image *ReadPICTImage(const ImageInfo *image_info)
   /*
     Open image file.
   */
-  OpenImage(image_info,image,ReadBinaryType);
-  if (image->file == (FILE *) NULL)
+  status=OpenBlob(image_info,image,ReadBinaryType);
+  if (status == False)
     PrematureExit(FileOpenWarning,"Unable to open file",image);
   picture_handle=(PicHandle)
     NewHandle(Max(image->filesize-PICTHeaderSize,PICTHeaderSize));
   if (picture_handle == nil)
     PrematureExit(ResourceLimitWarning,"Unable to allocate memory",image);
   HLock((Handle) picture_handle);
-  (void) ReadData(*(char **) picture_handle,1,PICTHeaderSize,image->file);
-  status=ReadData(*(char **) picture_handle,1,image->filesize-PICTHeaderSize,
-    image->file);
+  (void) ReadBlob(image,PICTHeaderSize,*(char **) picture_handle);
+  status=
+    ReadBlob(image,image->filesize-PICTHeaderSize,*(char **) picture_handle);
   HUnlock((Handle) picture_handle);
   if (status == False)
     {
@@ -1241,7 +1241,7 @@ Image *ReadPICTImage(const ImageInfo *image_info)
   if (picture_info.theColorTable != nil)
     DisposeHandle((Handle) picture_info.theColorTable);
   DisposeGWorld(graphic_world);
-  CloseImage(image);
+  CloseBlob(image);
   return(image);
 }
 
