@@ -53,6 +53,9 @@
 */
 #include "magick.h"
 #include "defines.h"
+#if defined(HasBZLIB)
+#include "bzlib.h"
+#endif
 #if defined(HasZLIB)
 #include "zlib.h"
 #endif
@@ -123,14 +126,14 @@ Export Image *ReadMIFFImage(const ImageInfo *image_info)
   /*
     Open image file.
   */
-  OpenImage(image_info,image,ReadBinaryType);
-  if (image->file == (FILE *) NULL)
+  status=OpenBlob(image_info,image,ReadBinaryType);
+  if (status == False)
     ReaderExit(FileOpenWarning,"Unable to open file",image);
   image->depth=8;
   /*
     Decode image header;  header terminates one character beyond a ':'.
   */
-  c=fgetc(image->file);
+  c=ReadByte(image);
   if (c == EOF)
     {
       DestroyImage(image);
@@ -165,7 +168,7 @@ Export Image *ReadMIFFImage(const ImageInfo *image_info)
             }
           for ( ; image->comments != (char *) NULL; p++)
           {
-            c=fgetc(image->file);
+            c=ReadByte(image);
             if ((c == EOF) || (c == '}'))
               break;
             if ((p-image->comments+1) >= (int) length)
@@ -184,7 +187,7 @@ Export Image *ReadMIFFImage(const ImageInfo *image_info)
             ReaderExit(ResourceLimitWarning,"Memory allocation failed",
               image);
           *p='\0';
-          c=fgetc(image->file);
+          c=ReadByte(image);
         }
       else
         if (isalnum(c))
@@ -197,27 +200,27 @@ Export Image *ReadMIFFImage(const ImageInfo *image_info)
             {
               if ((p-keyword) < (MaxTextExtent-1))
                 *p++=(char) c;
-              c=fgetc(image->file);
+              c=ReadByte(image);
             } while (isalnum(c) || (c == '-'));
             *p='\0';
             while (isspace(c) || (c == '='))
-              c=fgetc(image->file);
+              c=ReadByte(image);
             p=value;
             if (c != '"')
               while (!isspace(c) && (c != EOF))
               {
                 if ((p-value) < (MaxTextExtent-1))
                   *p++=(char) c;
-                c=fgetc(image->file);
+                c=ReadByte(image);
               }
             else
               {
-                c=fgetc(image->file);
+                c=ReadByte(image);
                 while ((c != '"') && (c != EOF))
                 {
                   if ((p-value) < (MaxTextExtent-1))
                     *p++=(char) c;
-                  c=fgetc(image->file);
+                  c=ReadByte(image);
                 }
               }
             *p='\0';
@@ -233,7 +236,7 @@ Export Image *ReadMIFFImage(const ImageInfo *image_info)
                 image->background_color.index=0;
               }
             if (Latin1Compare(keyword,"blue-primary") == 0)
-              (void) sscanf(value,"%f,%f",&image->chromaticity.blue_primary.x,
+              (void) sscanf(value,"%lf,%lf",&image->chromaticity.blue_primary.x,
                 &image->chromaticity.blue_primary.y);
             if (Latin1Compare(keyword,"border-color") == 0)
               {
@@ -295,7 +298,8 @@ Export Image *ReadMIFFImage(const ImageInfo *image_info)
             if (Latin1Compare(keyword,"gamma") == 0)
               image->gamma=atof(value);
             if (Latin1Compare(keyword,"green-primary") == 0)
-              (void) sscanf(value,"%f,%f",&image->chromaticity.green_primary.x,
+              (void) sscanf(value,"%lf,%lf",
+                &image->chromaticity.green_primary.x,
                 &image->chromaticity.green_primary.y);
             if (Latin1Compare(keyword,"id") == 0)
               {
@@ -338,7 +342,7 @@ Export Image *ReadMIFFImage(const ImageInfo *image_info)
             if (Latin1Compare(keyword,"packets") == 0)
               image->packets=(unsigned int) atoi(value);
             if (Latin1Compare(keyword,"red-primary") == 0)
-              (void) sscanf(value,"%f,%f",&image->chromaticity.red_primary.x,
+              (void) sscanf(value,"%lf,%lf",&image->chromaticity.red_primary.x,
                 &image->chromaticity.red_primary.y);
             if (Latin1Compare(keyword,"rendering-intent") == 0)
               {
@@ -357,7 +361,7 @@ Export Image *ReadMIFFImage(const ImageInfo *image_info)
                         image->rendering_intent=UndefinedIntent;
               }
             if (Latin1Compare(keyword,"resolution") == 0)
-              (void) sscanf(value,"%fx%f",&image->x_resolution,
+              (void) sscanf(value,"%lfx%lf",&image->x_resolution,
                 &image->y_resolution);
             if (Latin1Compare(keyword,"rows") == 0)
               image->rows=(unsigned int) atoi(value);
@@ -377,15 +381,15 @@ Export Image *ReadMIFFImage(const ImageInfo *image_info)
                       image->units=PixelsPerCentimeterResolution;
               }
             if (Latin1Compare(keyword,"white-point") == 0)
-              (void) sscanf(value,"%f,%f",&image->chromaticity.white_point.x,
+              (void) sscanf(value,"%lf,%lf",&image->chromaticity.white_point.x,
                 &image->chromaticity.white_point.y);
           }
         else
-          c=fgetc(image->file);
+          c=ReadByte(image);
       while (isspace(c))
-        c=fgetc(image->file);
+        c=ReadByte(image);
     }
-    (void) fgetc(image->file);
+    (void) ReadByte(image);
     /*
       Verify that required image information is defined.
     */
@@ -395,7 +399,7 @@ Export Image *ReadMIFFImage(const ImageInfo *image_info)
       ReaderExit(CorruptImageWarning,"Incorrect image header in file",image);
     if (image_info->ping)
       {
-        CloseImage(image);
+        CloseBlob(image);
         return(image);
       }
     if (image->montage != (char *) NULL)
@@ -426,7 +430,7 @@ Export Image *ReadMIFFImage(const ImageInfo *image_info)
                   image);
               p=image->directory+Extent(image->directory);
             }
-          c=fgetc(image->file);
+          c=ReadByte(image);
           *p++=(unsigned char) c;
         } while (c != '\0');
       }
@@ -440,8 +444,8 @@ Export Image *ReadMIFFImage(const ImageInfo *image_info)
         if (image->color_profile.info == (unsigned char *) NULL)
           ReaderExit(CorruptImageWarning,"Unable to read color profile",
             image);
-        (void) fread(image->color_profile.info,1,image->color_profile.length,
-          image->file);
+        (void) ReadBlob(image,image->color_profile.length,
+          (char *) image->color_profile.info);
       }
     if (image->class == PseudoClass)
       {
@@ -489,8 +493,8 @@ Export Image *ReadMIFFImage(const ImageInfo *image_info)
             if (colormap == (unsigned char *) NULL)
               ReaderExit(ResourceLimitWarning,"Memory allocation failed",
                 image);
-            (void) ReadData((char *) colormap,1,packet_size*image->colors,
-              image->file);
+            (void) ReadBlob(image,packet_size*image->colors,
+              (char *) colormap);
             p=colormap;
             for (i=0; i < (int) image->colors; i++)
             {
@@ -538,8 +542,8 @@ Export Image *ReadMIFFImage(const ImageInfo *image_info)
     */
     if ((image->compression != RunlengthEncodedCompression) ||
         (image->packets != 0))
-      (void) ReadData((char *) image->packed_pixels,1,(unsigned int)
-        max_packets*packet_size,image->file);
+      (void) ReadBlob(image,(unsigned int) max_packets*packet_size,
+        (char *) image->packed_pixels);
     else
       {
         /*
@@ -549,7 +553,7 @@ Export Image *ReadMIFFImage(const ImageInfo *image_info)
         p=image->packed_pixels;
         do
         {
-          (void) ReadData((char *) p,1,packet_size,image->file);
+          (void) ReadBlob(image,packet_size,(char *) p);
           image->packets++;
           p+=(packet_size-1);
           count+=(*p+1);
@@ -630,7 +634,7 @@ Export Image *ReadMIFFImage(const ImageInfo *image_info)
         break;
     do
     {
-      c=fgetc(image->file);
+      c=ReadByte(image);
     } while (!isgraph(c) && (c != EOF));
     if (c != EOF)
       {
@@ -644,13 +648,13 @@ Export Image *ReadMIFFImage(const ImageInfo *image_info)
             return((Image *) NULL);
           }
         image=image->next;
-        ProgressMonitor(LoadImagesText,(unsigned int) ftell(image->file),
+        ProgressMonitor(LoadImagesText,(unsigned int) TellBlob(image),
           (unsigned int) image->filesize);
       }
   } while (c != EOF);
   while (image->previous != (Image *) NULL)
     image=image->previous;
-  CloseImage(image);
+  CloseBlob(image);
   return(image);
 }
 
@@ -686,6 +690,7 @@ Export Image *ReadMIFFImage(const ImageInfo *image_info)
 Export unsigned int WriteMIFFImage(const ImageInfo *image_info,Image *image)
 {
   char
+    buffer[MaxTextExtent],
     color[MaxTextExtent];
 
   CompressionType
@@ -695,7 +700,8 @@ Export unsigned int WriteMIFFImage(const ImageInfo *image_info,Image *image)
     i;
 
   unsigned int
-    scene;
+    scene,
+    status;
 
   unsigned long
     packets;
@@ -703,8 +709,8 @@ Export unsigned int WriteMIFFImage(const ImageInfo *image_info,Image *image)
   /*
     Open output image file.
   */
-  OpenImage(image_info,image,WriteBinaryType);
-  if (image->file == (FILE *) NULL)
+  status=OpenBlob(image_info,image,WriteBinaryType);
+  if (status == False)
     WriterExit(FileOpenWarning,"Unable to open file",image);
   CondenseImage(image);
   if (image->class == DirectClass)
@@ -827,29 +833,32 @@ Export unsigned int WriteMIFFImage(const ImageInfo *image_info,Image *image)
     /*
       Write header to file.
     */
-    (void) fprintf(image->file,"id=ImageMagick\n");
+    (void) strcpy(buffer,"id=ImageMagick\n");
+    (void) WriteBlob(image,strlen(buffer),buffer);
     if (image->class == PseudoClass)
-      (void) fprintf(image->file,"class=PseudoClass  colors=%u\n",
-        image->colors);
+      (void) sprintf(buffer,"class=PseudoClass  colors=%u\n",image->colors);
     else
       if (image->matte)
-        (void) fprintf(image->file,"class=DirectClass  matte=True\n");
+        (void) strcpy(buffer,"class=DirectClass  matte=True\n");
       else
         if (image->colorspace == CMYKColorspace)
-          (void) fprintf(image->file,"class=DirectClass  colorspace=CMYK\n");
+          (void) strcpy(buffer,"class=DirectClass  colorspace=CMYK\n");
         else
-          (void) fprintf(image->file,"class=DirectClass\n");
+          (void) strcpy(buffer,"class=DirectClass\n");
+    (void) WriteBlob(image,strlen(buffer),buffer);
     if (image->compression == RunlengthEncodedCompression)
-      (void) fprintf(image->file,"compression=RunlengthEncoded  packets=%lu\n",
+      (void) sprintf(buffer,"compression=RunlengthEncoded  packets=%lu\n",
         packets);
     else
       if (image->compression == BZipCompression)
-        (void) fprintf(image->file,"compression=BZip  packets=%lu\n",packets);
+        (void) sprintf(buffer,"compression=BZip  packets=%lu\n",packets);
       else
         if (image->compression != NoCompression)
-          (void) fprintf(image->file,"compression=Zip  packets=%lu\n",packets);
-    (void) fprintf(image->file,"columns=%u  rows=%u  depth=%u\n",image->columns,
+          (void) sprintf(buffer,"compression=Zip  packets=%lu\n",packets);
+    (void) WriteBlob(image,strlen(buffer),buffer);
+    (void) sprintf(buffer,"columns=%u  rows=%u  depth=%u\n",image->columns,
       image->rows,image->depth);
+    (void) WriteBlob(image,strlen(buffer),buffer);
     if ((image->x_resolution != 0) && (image->y_resolution != 0))
       {
         char
@@ -863,87 +872,132 @@ Export unsigned int WriteMIFFImage(const ImageInfo *image_info,Image *image)
           (void) strcpy(units,"pixels-per-inch");
         if (image->units == PixelsPerCentimeterResolution)
           (void) strcpy(units,"pixels-per-centimeter");
-        (void) fprintf(image->file,"resolution=%gx%g  units=%.1024s\n",
+        (void) sprintf(buffer,"resolution=%gx%g  units=%.1024s\n",
           image->x_resolution,image->y_resolution,units);
+        (void) WriteBlob(image,strlen(buffer),buffer);
       }
     SignatureImage(image);
     if (image->signature != (char *) NULL)
-      (void) fprintf(image->file,"signature=%.1024s\n",image->signature);
+      {
+        (void) sprintf(buffer,"signature=%.1024s\n",image->signature);
+        (void) WriteBlob(image,strlen(buffer),buffer);
+      }
     if (image->page != (char *) NULL)
-      (void) fprintf(image->file,"page=%.1024s\n",image->page);
+      {
+        (void) sprintf(buffer,"page=%.1024s\n",image->page);
+        (void) WriteBlob(image,strlen(buffer),buffer);
+      }
     (void) QueryColorName(&image->background_color,color);
-    (void) fprintf(image->file,"background-color=%.1024s  ",color);
+    (void) sprintf(buffer,"background-color=%.1024s  ",color);
+    (void) WriteBlob(image,strlen(buffer),buffer);
     (void) QueryColorName(&image->border_color,color);
-    (void) fprintf(image->file,"border-color=%.1024s  ",color);
+    (void) sprintf(buffer,"border-color=%.1024s  ",color);
+    (void) WriteBlob(image,strlen(buffer),buffer);
     (void) QueryColorName(&image->matte_color,color);
-    (void) fprintf(image->file,"matte-color=%.1024s\n",color);
+    (void) sprintf(buffer,"matte-color=%.1024s\n",color);
+    (void) WriteBlob(image,strlen(buffer),buffer);
     if ((image->next != (Image *) NULL) || (image->previous != (Image *) NULL))
-      (void) fprintf(image->file,
-        "scene=%u  iterations=%u  delay=%u  dispose=%u\n",
-        image->scene,image->iterations,image->delay,image->dispose);
+      {
+        (void) sprintf(buffer,"scene=%u  iterations=%u  delay=%u  dispose=%u\n",
+          image->scene,image->iterations,image->delay,image->dispose);
+        (void) WriteBlob(image,strlen(buffer),buffer);
+      }
     else
       {
         if (image->scene != 0)
-          (void) fprintf(image->file,"scene=%u\n",image->scene);
+          {
+            (void) sprintf(buffer,"scene=%u\n",image->scene);
+            (void) WriteBlob(image,strlen(buffer),buffer);
+          }
         if (image->iterations != 1)
-          (void) fprintf(image->file,"iterations=%u\n",image->iterations);
+          {
+            (void) sprintf(buffer,"iterations=%u\n",image->iterations);
+            (void) WriteBlob(image,strlen(buffer),buffer);
+          }
         if (image->delay != 0)
-          (void) fprintf(image->file,"delay=%u\n",image->delay);
+          {
+            (void) sprintf(buffer,"delay=%u\n",image->delay);
+            (void) WriteBlob(image,strlen(buffer),buffer);
+          }
         if (image->dispose != 0)
-          (void) fprintf(image->file,"dispose=%u\n",image->dispose);
+          {
+            (void) sprintf(buffer,"dispose=%u\n",image->dispose);
+            (void) WriteBlob(image,strlen(buffer),buffer);
+          }
       }
     if (image->rendering_intent != UndefinedIntent)
       {
         if (image->rendering_intent == SaturationIntent)
-          (void) fprintf(image->file,"rendering-intent=saturation\n");
+          (void) strcpy(buffer,"rendering-intent=saturation\n");
         else
           if (image->rendering_intent == PerceptualIntent)
-            (void) fprintf(image->file,"rendering-intent=perceptual\n");
+            (void) strcpy(buffer,"rendering-intent=perceptual\n");
           else
             if (image->rendering_intent == AbsoluteIntent)
-              (void) fprintf(image->file,"rendering-intent=absolute\n");
+              (void) strcpy(buffer,"rendering-intent=absolute\n");
             else
-              (void) fprintf(image->file,"rendering-intent=relative\n");
+              (void) strcpy(buffer,"rendering-intent=relative\n");
+        (void) WriteBlob(image,strlen(buffer),buffer);
       }
     if (image->gamma != 0.0)
-      (void) fprintf(image->file,"gamma=%g\n",image->gamma);
+      {
+        (void) sprintf(buffer,"gamma=%g\n",image->gamma);
+        (void) WriteBlob(image,strlen(buffer),buffer);
+      }
     if (image->chromaticity.white_point.x != 0.0)
       {
         /*
           Note chomaticity points.
         */
-        (void) fprintf(image->file,
+        (void) sprintf(buffer,
           "red-primary=%g,%g  green-primary=%g,%g  blue-primary=%g,%g\n",
           image->chromaticity.red_primary.x,image->chromaticity.red_primary.y,
           image->chromaticity.green_primary.x,
           image->chromaticity.green_primary.y,
           image->chromaticity.blue_primary.x,
           image->chromaticity.blue_primary.y);
-        (void) fprintf(image->file,"white-point=%g,%g\n",
+        (void) WriteBlob(image,strlen(buffer),buffer);
+        (void) sprintf(buffer,"white-point=%g,%g\n",
           image->chromaticity.white_point.x,image->chromaticity.white_point.y);
+        (void) WriteBlob(image,strlen(buffer),buffer);
       }
     if (image->color_profile.length > 0)
-      (void) fprintf(image->file,"color-profile=%u\n",
-        image->color_profile.length);
+      {
+        (void) sprintf(buffer,"color-profile=%u\n",image->color_profile.length);
+        (void) WriteBlob(image,strlen(buffer),buffer);
+      }
     if (image->montage != (char *) NULL)
-      (void) fprintf(image->file,"montage=%.1024s\n",image->montage);
+      {
+        (void) sprintf(buffer,"montage=%.1024s\n",image->montage);
+        (void) WriteBlob(image,strlen(buffer),buffer);
+      }
     if (image->label != (char *) NULL)
-      (void) fprintf(image->file,"label=\"%.1024s\"\n",image->label);
+      {
+        (void) sprintf(buffer,"label=\"%.1024s\"\n",image->label);
+        (void) WriteBlob(image,strlen(buffer),buffer);
+      }
     if (image->comments != (char *) NULL)
-      (void) fprintf(image->file,"{%s}\n",image->comments);
-    (void) fprintf(image->file,"\f\n:\032");
+      {
+        (void) WriteByte(image,'{');
+        (void) WriteByte(image,'\n');
+        (void) WriteBlob(image,strlen(image->comments),image->comments);
+        (void) WriteByte(image,'}');
+        (void) WriteByte(image,'\n');
+      }
+    (void) strcpy(buffer,"\f\n:\032");
+    (void) WriteBlob(image,strlen(buffer),buffer);
     if (image->montage != (char *) NULL)
       {
         /*
           Write montage tile directory.
         */
         if (image->directory != (char *) NULL)
-          (void) fprintf(image->file,"%s",image->directory);
-        (void) fputc('\0',image->file);
+          (void) WriteBlob(image,strlen(image->directory),image->directory);
+        (void) WriteByte(image,'\0');
       }
     if (image->color_profile.length > 0)
-      (void) fwrite((char *) image->color_profile.info,1,(int)
-        image->color_profile.length,image->file);
+      (void) WriteBlob(image,(int) image->color_profile.length,
+        (char *) image->color_profile.info);
     if (image->class == PseudoClass)
       {
         register unsigned char
@@ -976,15 +1030,15 @@ Export unsigned int WriteMIFFImage(const ImageInfo *image_info,Image *image)
         /*
           Write colormap to file.
         */
-        (void) fwrite((char *) colormap,1,(int) image->colors*packet_size,
-          image->file);
+        (void) WriteBlob(image,(int) image->colors*packet_size,
+          (char *) colormap);
         FreeMemory((char *) colormap);
       }
     /*
       Write image pixels to file.
     */
-    (void) fwrite((char *) image->packed_pixels,(int) image->packet_size,
-      (int) packets,image->file);
+    (void) WriteBlob(image,image->packet_size*packets,
+      (char *) image->packed_pixels);
     if (image->next == (Image *) NULL)
       break;
     image->next->file=image->file;
@@ -994,6 +1048,6 @@ Export unsigned int WriteMIFFImage(const ImageInfo *image_info,Image *image)
   if (image_info->adjoin)
     while (image->previous != (Image *) NULL)
       image=image->previous;
-  CloseImage(image);
+  CloseBlob(image);
   return(True);
 }
