@@ -212,7 +212,7 @@ static void FormatLabel(ImageInfo *image_info,char *label,
   for (q=p+1; *q != '\0'; q++)
   {
     (void) strcpy(image_info->filename,"label:");
-    (void) strncat(image_info->filename+6,p,(int) (q-p));
+    (void) strncat(image_info->filename+6,p,(int) (q-p+1));
     image=ReadImage(image_info);
     if (image == (Image *) NULL)
       break;
@@ -330,6 +330,7 @@ Export Image *MontageImages(const Image *images,const MontageInfo *montage_info)
     height=image_list[tile]->rows;
     x=0;
     y=0;
+    image_list[tile]->orphan=True;
     (void) ParseImageGeometry(montage_info->geometry,&x,&y,&width,&height);
     image_list[tile]->orphan=True;
     tiled_image=ZoomImage(image_list[tile],width,height);
