@@ -99,7 +99,7 @@ static unsigned int PNMInteger(Image *image,const unsigned int base)
   */
   do
   {
-    c=fgetc(image->file);
+    c=ReadByte(image);
     if (c == EOF)
       return(0);
     if (c == '#')
@@ -139,7 +139,7 @@ static unsigned int PNMInteger(Image *image,const unsigned int base)
                   break;
                 p=image->comments+Extent(image->comments);
               }
-            c=fgetc(image->file);
+            c=ReadByte(image);
             *p=(char) c;
             *(p+1)='\0';
           }
@@ -164,7 +164,7 @@ static unsigned int PNMInteger(Image *image,const unsigned int base)
   {
     value*=10;
     value+=c-'0';
-    c=fgetc(image->file);
+    c=ReadByte(image);
     if (c == EOF)
       return(0);
   }
@@ -205,9 +205,6 @@ Export Image *ReadPNMImage(const ImageInfo *image_info)
     max_value,
     status;
 
-  unsigned long
-    max_packets;
-
   unsigned short
     blue,
     green,
@@ -223,13 +220,13 @@ Export Image *ReadPNMImage(const ImageInfo *image_info)
   /*
     Open image file.
   */
-  OpenImage(image_info,image,ReadBinaryType);
-  if (image->file == (FILE *) NULL)
+  status=OpenBlob(image_info,image,ReadBinaryType);
+  if (status == False)
     ReaderExit(FileOpenWarning,"Unable to open file",image);
   /*
     Read PNM image.
   */
-  status=ReadData((char *) &format,1,1,image->file);
+  status=ReadBlob(image,1,(char *) &format);
   do
   {
     /*
@@ -240,7 +237,7 @@ Export Image *ReadPNMImage(const ImageInfo *image_info)
     /*
       Initialize image structure.
     */
-    format=fgetc(image->file);
+    format=ReadByte(image);
     if (format == '7')
       (void) PNMInteger(image,10);
     image->columns=PNMInteger(image,10);
@@ -256,20 +253,12 @@ Export Image *ReadPNMImage(const ImageInfo *image_info)
       }
     if (image_info->ping)
       {
-        CloseImage(image);
+        CloseBlob(image);
         return(image);
       }
     if ((image->columns*image->rows) == 0)
       ReaderExit(CorruptImageWarning,
         "Unable to read image: image dimensions are zero",image);
-    packets=0;
-    max_packets=Max((image->columns*image->rows+4) >> 3,1);
-    if ((format == '1') || (format == '4'))
-      max_packets=Max((image->columns*image->rows+8) >> 4,1);
-    image->pixels=(RunlengthPacket *)
-      AllocateMemory(max_packets*sizeof(RunlengthPacket));
-    if (image->pixels == (RunlengthPacket *) NULL)
-      ReaderExit(ResourceLimitWarning,"Memory allocation failed",image);
     scale=(Quantum *) NULL;
     if (image->class == PseudoClass)
       {
@@ -315,11 +304,15 @@ Export Image *ReadPNMImage(const ImageInfo *image_info)
           */
           scale=(Quantum *) AllocateMemory((max_value+1)*sizeof(Quantum));
           if (scale == (Quantum *) NULL)
-            ReaderExit(ResourceLimitWarning,"Memory allocation failed",
-              image);
+            ReaderExit(ResourceLimitWarning,"Memory allocation failed",image);
           for (i=0; i <= (int) max_value; i++)
             scale[i]=(Quantum) ((i*MaxRGB+(max_value >> 1))/max_value);
         }
+    packets=0;
+    image->pixels=(RunlengthPacket *)
+      AllocateMemory(image->columns*image->rows*sizeof(RunlengthPacket));
+    if (image->pixels == (RunlengthPacket *) NULL)
+      ReaderExit(ResourceLimitWarning,"Memory allocation failed",image);
     /*
       Convert PNM pixels to runlength-encoded MIFF packets.
     */
@@ -344,16 +337,6 @@ Export Image *ReadPNMImage(const ImageInfo *image_info)
                 if (packets != 0)
                   q++;
                 packets++;
-                if (packets == (int) max_packets)
-                  {
-                    max_packets<<=1;
-                    image->pixels=(RunlengthPacket *) ReallocateMemory((char *)
-                      image->pixels,max_packets*sizeof(RunlengthPacket));
-                    if (image->pixels == (RunlengthPacket *) NULL)
-                      ReaderExit(ResourceLimitWarning,
-                        "Memory allocation failed",image);
-                    q=image->pixels+packets-1;
-                  }
                 q->index=index;
                 q->length=0;
               }
@@ -381,20 +364,6 @@ Export Image *ReadPNMImage(const ImageInfo *image_info)
                 if (packets != 0)
                   q++;
                 packets++;
-                if (packets == (int) max_packets)
-                  {
-                    max_packets<<=1;
-                    image->pixels=(RunlengthPacket *) ReallocateMemory((char *)
-                      image->pixels,max_packets*sizeof(RunlengthPacket));
-                    if (image->pixels == (RunlengthPacket *) NULL)
-                      {
-                        if (scale != (Quantum *) NULL)
-                          FreeMemory((char *) scale);
-                        ReaderExit(ResourceLimitWarning,
-                          "Memory allocation failed",image);
-                      }
-                    q=image->pixels+packets-1;
-                  }
                 q->index=index;
                 q->length=0;
               }
@@ -431,20 +400,6 @@ Export Image *ReadPNMImage(const ImageInfo *image_info)
                 if (packets != 0)
                   q++;
                 packets++;
-                if (packets == (int) max_packets)
-                  {
-                    max_packets<<=1;
-                    image->pixels=(RunlengthPacket *) ReallocateMemory((char *)
-                      image->pixels,max_packets*sizeof(RunlengthPacket));
-                    if (image->pixels == (RunlengthPacket *) NULL)
-                      {
-                        if (scale != (Quantum *) NULL)
-                          FreeMemory((char *) scale);
-                        ReaderExit(ResourceLimitWarning,
-                          "Memory allocation failed",image);
-                      }
-                    q=image->pixels+packets-1;
-                  }
                 q->red=red;
                 q->green=green;
                 q->blue=blue;
@@ -474,7 +429,7 @@ Export Image *ReadPNMImage(const ImageInfo *image_info)
           for (x=0; x < (int) image->columns; x++)
           {
             if (bit == 0)
-              byte=fgetc(image->file);
+              byte=ReadByte(image);
             index=(byte & 0x80) ? 0 : 1;
             if ((index == q->index) && ((int) q->length < MaxRunlength))
               q->length++;
@@ -483,16 +438,6 @@ Export Image *ReadPNMImage(const ImageInfo *image_info)
                 if (packets != 0)
                   q++;
                 packets++;
-                if (packets == (int) max_packets)
-                  {
-                    max_packets<<=1;
-                    image->pixels=(RunlengthPacket *) ReallocateMemory((char *)
-                      image->pixels,max_packets*sizeof(RunlengthPacket));
-                    if (image->pixels == (RunlengthPacket *) NULL)
-                      ReaderExit(ResourceLimitWarning,
-                        "Memory allocation failed",image);
-                    q=image->pixels+packets-1;
-                  }
                 q->index=index;
                 q->length=0;
               }
@@ -518,9 +463,9 @@ Export Image *ReadPNMImage(const ImageInfo *image_info)
           for (x=0; x < (int) image->columns; x++)
           {
             if (max_value <= MaxRawValue)
-              index=fgetc(image->file);
+              index=ReadByte(image);
             else
-              index=LSBFirstReadShort(image->file);
+              index=LSBFirstReadShort(image);
             if (index > max_value)
               index=max_value;
             if ((index == q->index) && ((int) q->length < MaxRunlength))
@@ -530,16 +475,6 @@ Export Image *ReadPNMImage(const ImageInfo *image_info)
                 if (packets != 0)
                   q++;
                 packets++;
-                if (packets == (int) max_packets)
-                  {
-                    max_packets<<=1;
-                    image->pixels=(RunlengthPacket *) ReallocateMemory((char *)
-                      image->pixels,max_packets*sizeof(RunlengthPacket));
-                    if (image->pixels == (RunlengthPacket *) NULL)
-                      ReaderExit(ResourceLimitWarning,
-                        "Memory allocation failed",image);
-                    q=image->pixels+packets-1;
-                  }
                 q->index=index;
                 q->length=0;
               }
@@ -561,15 +496,15 @@ Export Image *ReadPNMImage(const ImageInfo *image_info)
           {
             if (max_value <= MaxRawValue)
               {
-                red=fgetc(image->file);
-                green=fgetc(image->file);
-                blue=fgetc(image->file);
+                red=ReadByte(image);
+                green=ReadByte(image);
+                blue=ReadByte(image);
               }
             else
               {
-                red=LSBFirstReadShort(image->file);
-                green=LSBFirstReadShort(image->file);
-                blue=LSBFirstReadShort(image->file);
+                red=LSBFirstReadShort(image);
+                green=LSBFirstReadShort(image);
+                blue=LSBFirstReadShort(image);
               }
             if (scale != (Quantum *) NULL)
               {
@@ -585,20 +520,6 @@ Export Image *ReadPNMImage(const ImageInfo *image_info)
                 if (packets != 0)
                   q++;
                 packets++;
-                if (packets == (int) max_packets)
-                  {
-                    max_packets<<=1;
-                    image->pixels=(RunlengthPacket *) ReallocateMemory((char *)
-                      image->pixels,max_packets*sizeof(RunlengthPacket));
-                    if (image->pixels == (RunlengthPacket *) NULL)
-                      {
-                        if (scale != (Quantum *) NULL)
-                          FreeMemory((char *) scale);
-                        ReaderExit(ResourceLimitWarning,
-                          "Memory allocation failed",image);
-                      }
-                    q=image->pixels+packets-1;
-                  }
                 q->red=red;
                 q->green=green;
                 q->blue=blue;
@@ -619,7 +540,7 @@ Export Image *ReadPNMImage(const ImageInfo *image_info)
     }
     if (scale != (Quantum *) NULL)
       FreeMemory((char *) scale);
-    if (feof(image->file))
+    if (EOFBlob(image))
       MagickWarning(CorruptImageWarning,"not enough pixels",image->filename);
     SetRunlengthPackets(image,packets);
     if (image->class == PseudoClass)
@@ -636,11 +557,11 @@ Export Image *ReadPNMImage(const ImageInfo *image_info)
         /*
           Skip to end of line.
         */
-        status=ReadData(&format,1,1,image->file);
+        status=ReadBlob(image,1,&format);
         if (status == False)
           break;
       } while (format != '\n');
-    status=ReadData((char *) &format,1,1,image->file);
+    status=ReadBlob(image,1,(char *) &format);
     if ((status == True) && (format == 'P'))
       {
         /*
@@ -653,13 +574,13 @@ Export Image *ReadPNMImage(const ImageInfo *image_info)
             return((Image *) NULL);
           }
         image=image->next;
-        ProgressMonitor(LoadImagesText,(unsigned int) ftell(image->file),
+        ProgressMonitor(LoadImagesText,(unsigned int) TellBlob(image),
           (unsigned int) image->filesize);
       }
   } while ((status == True) && (format == 'P'));
   while (image->previous != (Image *) NULL)
     image=image->previous;
-  CloseImage(image);
+  CloseBlob(image);
   return(image);
 }
 
@@ -698,6 +619,7 @@ Export unsigned int WritePNMImage(const ImageInfo *image_info,Image *image)
 #define MaxRawValue  255
 
   char
+    buffer[MaxTextExtent],
     *magick;
 
   int
@@ -715,7 +637,8 @@ Export unsigned int WritePNMImage(const ImageInfo *image_info,Image *image)
     format;
 
   unsigned int
-    scene;
+    scene,
+    status;
 
   unsigned short
     index;
@@ -723,8 +646,8 @@ Export unsigned int WritePNMImage(const ImageInfo *image_info,Image *image)
   /*
     Open output image file.
   */
-  OpenImage(image_info,image,WriteBinaryType);
-  if (image->file == (FILE *) NULL)
+  status=OpenBlob(image_info,image,WriteBinaryType);
+  if (status == False)
     WriterExit(FileOpenWarning,"Unable to open file",image);
   scene=0;
   do
@@ -795,10 +718,11 @@ Export unsigned int WritePNMImage(const ImageInfo *image_info,Image *image)
     if (Latin1Compare(magick,"P7") == 0)
       {
         format='7';
-        (void) fprintf(image->file,"P7 332\n");
+        (void) strcpy(buffer,"P7 332\n");
       }
     else
-      (void) fprintf(image->file,"P%c\n",format);
+      (void) sprintf(buffer,"P%c\n",format);
+    (void) WriteBlob(image,strlen(buffer),buffer);
     if (image->comments != (char *) NULL)
       {
         register char
@@ -807,17 +731,20 @@ Export unsigned int WritePNMImage(const ImageInfo *image_info,Image *image)
         /*
           Write comments to file.
         */
-        (void) fprintf(image->file,"#");
+        (void) WriteByte(image,'#');
         for (p=image->comments; *p != '\0'; p++)
         {
-          (void) fputc(*p,image->file);
+          (void) WriteByte(image,*p);
           if ((*p == '\n') && (*(p+1) != '\0'))
-            (void) fprintf(image->file,"#");
+            (void) WriteByte(image,'#');
         }
-        (void) fputc('\n',image->file);
+        (void) WriteByte(image,'\n');
       }
     if (format != '7')
-      (void) fprintf(image->file,"%u %u\n",image->columns,image->rows);
+      {
+        (void) sprintf(buffer,"%u %u\n",image->columns,image->rows);
+        (void) WriteBlob(image,strlen(buffer),buffer);
+      }
     /*
       Convert runlength encoded to PNM raster pixels.
     */
@@ -842,11 +769,12 @@ Export unsigned int WritePNMImage(const ImageInfo *image_info,Image *image)
         {
           for (j=0; j <= ((int) p->length); j++)
           {
-            (void) fprintf(image->file,"%d ",(int) (p->index == polarity));
+            (void) sprintf(buffer,"%d ",(int) (p->index == polarity));
+            (void) WriteBlob(image,strlen(buffer),buffer);
             x++;
             if (x == 36)
               {
-                (void) fprintf(image->file,"\n");
+                (void) WriteByte(image,'\n');
                 x=0;
               }
           }
@@ -862,17 +790,19 @@ Export unsigned int WritePNMImage(const ImageInfo *image_info,Image *image)
         /*
           Convert image to a PGM image.
         */
-        (void) fprintf(image->file,"%d\n",MaxRGB);
+        (void) sprintf(buffer,"%d\n",MaxRGB);
+        (void) WriteBlob(image,strlen(buffer),buffer);
         for (i=0; i < (int) image->packets; i++)
         {
-          index=DownScale(Intensity(*p));
+          index=Intensity(*p);
           for (j=0; j <= ((int) p->length); j++)
           {
-            (void) fprintf(image->file,"%d ",index);
+            (void) sprintf(buffer,"%d ",index);
+            (void) WriteBlob(image,strlen(buffer),buffer);
             x++;
             if (x == 12)
               {
-                (void) fprintf(image->file,"\n");
+                (void) WriteByte(image,'\n');
                 x=0;
               }
           }
@@ -888,16 +818,18 @@ Export unsigned int WritePNMImage(const ImageInfo *image_info,Image *image)
         /*
           Convert image to a PNM image.
         */
-        (void) fprintf(image->file,"%d\n",MaxRGB);
+        (void) sprintf(buffer,"%d\n",MaxRGB);
+        (void) WriteBlob(image,strlen(buffer),buffer);
         for (i=0; i < (int) image->packets; i++)
         {
           for (j=0; j <= ((int) p->length); j++)
           {
-            (void) fprintf(image->file,"%d %d %d ",p->red,p->green,p->blue);
+            (void) sprintf(buffer,"%d %d %d ",p->red,p->green,p->blue);
+            (void) WriteBlob(image,strlen(buffer),buffer);
             x++;
             if (x == 4)
               {
-                (void) fprintf(image->file,"\n");
+                (void) WriteByte(image,'\n');
                 x=0;
               }
           }
@@ -934,7 +866,7 @@ Export unsigned int WritePNMImage(const ImageInfo *image_info,Image *image)
             bit++;
             if (bit == 8)
               {
-                (void) fputc(byte,image->file);
+                (void) WriteByte(image,byte);
                 bit=0;
                 byte=0;
               }
@@ -945,7 +877,7 @@ Export unsigned int WritePNMImage(const ImageInfo *image_info,Image *image)
                   Advance to the next scanline.
                 */
                 if (bit != 0)
-                  (void) fputc(byte << (8-bit),image->file);
+                  (void) WriteByte(image,byte << (8-bit));
                 if (image->previous == (Image *) NULL)
                   if (QuantumTick(y,image->rows))
                     ProgressMonitor(SaveImageText,y,image->rows);
@@ -964,12 +896,13 @@ Export unsigned int WritePNMImage(const ImageInfo *image_info,Image *image)
         /*
           Convert image to a PGM image.
         */
-        (void) fprintf(image->file,"%lu\n",DownScale(MaxRGB));
+        (void) sprintf(buffer,"%lu\n",DownScale(MaxRGB));
+        (void) WriteBlob(image,strlen(buffer),buffer);
         for (i=0; i < (int) image->packets; i++)
         {
           index=DownScale(Intensity(*p));
           for (j=0; j <= ((int) p->length); j++)
-            (void) fputc(index,image->file);
+            (void) WriteByte(image,index);
           p++;
           if (image->previous == (Image *) NULL)
             if (QuantumTick(i,image->packets))
@@ -995,7 +928,8 @@ Export unsigned int WritePNMImage(const ImageInfo *image_info,Image *image)
         /*
           Convert image to a PNM image.
         */
-        (void) fprintf(image->file,"%lu\n",DownScale(MaxRGB));
+        (void) sprintf(buffer,"%lu\n",DownScale(MaxRGB));
+        (void) WriteBlob(image,strlen(buffer),buffer);
         q=pixels;
         for (i=0; i < (int) image->packets; i++)
         {
@@ -1007,7 +941,7 @@ Export unsigned int WritePNMImage(const ImageInfo *image_info,Image *image)
             x++;
             if (x == (int) image->columns)
               {
-                (void) fwrite((char *) pixels,1,q-pixels,image->file);
+                (void) WriteBlob(image,q-pixels,(char *) pixels);
                 if (image->previous == (Image *) NULL)
                   if (QuantumTick(y,image->rows))
                     ProgressMonitor(SaveImageText,y,image->rows);
@@ -1044,7 +978,10 @@ Export unsigned int WritePNMImage(const ImageInfo *image_info,Image *image)
           value;
 
         Quantum
-          pixel;
+          blue,
+          green,
+          pixel,
+          red;
 
         unsigned short
           *blue_map[2][16],
@@ -1083,26 +1020,27 @@ Export unsigned int WritePNMImage(const ImageInfo *image_info,Image *image)
                 value=x/2+8;
               value+=dither_red[i][j];
               red_map[i][j][x]=(unsigned short)
-                ((value < 0) ? 0 : (value > MaxRGB) ? MaxRGB : value);
+                ((value < 0) ? 0 : (value > 255) ? 255 : value);
               value=x-16;
               if (x < 48)
                 value=x/2+8;
               value+=dither_green[i][j];
               green_map[i][j][x]=(unsigned short)
-                ((value < 0) ? 0 : (value > MaxRGB) ? MaxRGB : value);
+                ((value < 0) ? 0 : (value > 255) ? 255 : value);
               value=x-32;
               if (x < 112)
                 value=x/2+24;
               value+=(dither_blue[i][j] << 1);
               blue_map[i][j][x]=(unsigned short)
-                ((value < 0) ? 0 : (value > MaxRGB) ? MaxRGB : value);
+                ((value < 0) ? 0 : (value > 255) ? 255 : value);
             }
         /*
           Convert image to a P7 image.
         */
-        (void) fprintf(image->file,"#END_OF_COMMENTS\n");
-        (void) fprintf(image->file,"%u %u %d\n",image->columns,image->rows,
-          MaxRGB);
+        (void) strcpy(buffer,"#END_OF_COMMENTS\n");
+        (void) WriteBlob(image,strlen(buffer),buffer);
+        (void) sprintf(buffer,"%u %u 255\n",image->columns,image->rows);
+        (void) WriteBlob(image,strlen(buffer),buffer);
         i=0;
         j=0;
         p=image->pixels;
@@ -1110,10 +1048,13 @@ Export unsigned int WritePNMImage(const ImageInfo *image_info,Image *image)
         {
           for (x=0; x < (int) image->columns; x++)
           {
-            pixel=(Quantum) ((red_map[i][j][p->red] & 0xe0) |
-              ((unsigned int) (green_map[i][j][p->green] & 0xe0) >> 3) |
-              ((unsigned int) (blue_map[i][j][p->blue] & 0xc0) >> 6));
-            WriteQuantumFile(pixel);
+            red=DownScale(p->red);
+            green=DownScale(p->green);
+            blue=DownScale(p->blue);
+            pixel=(Quantum) ((red_map[i][j][red] & 0xe0) |
+              ((unsigned int) (green_map[i][j][green] & 0xe0) >> 3) |
+              ((unsigned int) (blue_map[i][j][blue] & 0xc0) >> 6));
+            (void) WriteByte(image,pixel);
             p++;
             j++;
             if (j == 16)
@@ -1147,6 +1088,6 @@ Export unsigned int WritePNMImage(const ImageInfo *image_info,Image *image)
   if (image_info->adjoin)
     while (image->previous != (Image *) NULL)
       image=image->previous;
-  CloseImage(image);
+  CloseBlob(image);
   return(True);
 }
