@@ -122,6 +122,9 @@ Export Image *ReadPSImage(const ImageInfo *image_info)
     *image,
     *next_image;
 
+  ImageInfo
+    *local_info;
+
   int
     c,
     count,
@@ -166,8 +169,8 @@ Export Image *ReadPSImage(const ImageInfo *image_info)
   /*
     Open image file.
   */
-  OpenImage(image_info,image,ReadBinaryType);
-  if (image->file == (FILE *) NULL)
+  status=OpenBlob(image_info,image,ReadBinaryType);
+  if (status == False)
     ReaderExit(FileOpenWarning,"Unable to open file",image);
   /*
     Open temporary output file.
@@ -186,7 +189,7 @@ Export Image *ReadPSImage(const ImageInfo *image_info)
   if ((image->x_resolution == 0.0) || (image->y_resolution == 0.0))
     {
       (void) strcpy(density,PSDensityGeometry);
-      count=sscanf(density,"%fx%f",&image->x_resolution,&image->y_resolution);
+      count=sscanf(density,"%lfx%lf",&image->x_resolution,&image->y_resolution);
       if (count != 2)
         image->y_resolution=image->x_resolution;
     }
@@ -206,11 +209,11 @@ Export Image *ReadPSImage(const ImageInfo *image_info)
       /*
         Dos binary file header.
       */
-      (void) LSBFirstReadLong(image->file);
-      count=LSBFirstReadLong(image->file);
-      filesize=LSBFirstReadLong(image->file);
+      (void) LSBFirstReadLong(image);
+      count=LSBFirstReadLong(image);
+      filesize=LSBFirstReadLong(image);
       for (i=0; i < (count-12); i++)
-        (void) fgetc(image->file);
+        (void) ReadByte(image);
     }
   box.width=0;
   box.height=0;
@@ -222,7 +225,7 @@ Export Image *ReadPSImage(const ImageInfo *image_info)
   p=command;
   for (i=0; (Latin1Compare(image_info->magick,"EPT") != 0) || i < filesize; i++)
   {
-    c=fgetc(image->file);
+    c=ReadByte(image);
     if (c == EOF)
       break;
     (void) fputc(c,file);
@@ -240,13 +243,13 @@ Export Image *ReadPSImage(const ImageInfo *image_info)
     */
     count=0;
     if (strncmp(BoundingBox,command,Extent(BoundingBox)) == 0)
-      count=sscanf(command,"%%%%BoundingBox: %f %f %f %f",&bounding_box.x1,
+      count=sscanf(command,"%%%%BoundingBox: %lf %lf %lf %lf",&bounding_box.x1,
         &bounding_box.y1,&bounding_box.x2,&bounding_box.y2);
     if (strncmp(DocumentMedia,command,Extent(DocumentMedia)) == 0)
-      count=sscanf(command,"%%%%DocumentMedia: %*s %f %f",&bounding_box.x2,
+      count=sscanf(command,"%%%%DocumentMedia: %*s %lf %lf",&bounding_box.x2,
         &bounding_box.y2)+2;
     if (strncmp(PageBoundingBox,command,Extent(PageBoundingBox)) == 0)
-      count=sscanf(command,"%%%%PageBoundingBox: %f %f %f %f",
+      count=sscanf(command,"%%%%PageBoundingBox: %lf %lf %lf %lf",
         &bounding_box.x1,&bounding_box.y1,&bounding_box.x2,&bounding_box.y2);
     if (count != 4)
       continue;
@@ -256,12 +259,12 @@ Export Image *ReadPSImage(const ImageInfo *image_info)
     /*
       Set Postscript render geometry.
     */
-    FormatString(translate_geometry,"%f %f translate\n",-bounding_box.x1,
+    FormatString(translate_geometry,"%lf %lf translate\n",-bounding_box.x1,
       -bounding_box.y1);
-    width=(unsigned int) (bounding_box.x2-bounding_box.x1+1);
+    width=(unsigned int) (bounding_box.x2-bounding_box.x1);
     if ((float) ((int) bounding_box.x2) != bounding_box.x2)
       width++;
-    height=(unsigned int) (bounding_box.y2-bounding_box.y1+1);
+    height=(unsigned int) (bounding_box.y2-bounding_box.y1);
     if ((float) ((int) bounding_box.y2) != bounding_box.y2)
       height++;
     if ((width <= box.width) && (height <= box.height))
@@ -275,9 +278,9 @@ Export Image *ReadPSImage(const ImageInfo *image_info)
   if (image_info->page != (char *) NULL)
     (void) ParseImageGeometry(image_info->page,&page_info.x,&page_info.y,
       &page_info.width,&page_info.height);
-  FormatString(geometry,"%ux%u",(unsigned int) (((page_info.width*
-    image->x_resolution)/dx_resolution)+0.5),(unsigned int)
-    (((page_info.height*image->y_resolution)/dy_resolution)+0.5));
+  FormatString(geometry,"%ux%u",
+    (unsigned int) ((page_info.width*image->x_resolution+0.5)/dx_resolution),
+    (unsigned int) ((page_info.height*image->y_resolution+0.5)/dy_resolution));
   if (ferror(file))
     {
       MagickWarning(FileOpenWarning,"An error has occurred writing to file",
@@ -288,7 +291,7 @@ Export Image *ReadPSImage(const ImageInfo *image_info)
   (void) fseek(file,0L,SEEK_SET);
   (void) fputs(translate_geometry,file);
   (void) fclose(file);
-  CloseImage(image);
+  CloseBlob(image);
   filesize=image->filesize;
   DestroyImage(image);
   /*
@@ -300,7 +303,7 @@ Export Image *ReadPSImage(const ImageInfo *image_info)
       image_info->subimage+1,image_info->subimage+image_info->subrange);
   (void) strcpy(filename,image_info->filename);
   TemporaryFilename((char *) image_info->filename);
-  FormatString(command,delegate_info.commands,image_info->antialias ? 1 : 1,
+  FormatString(command,delegate_info.commands,image_info->antialias ? 4 : 1,
     image_info->antialias ? 4 : 1,geometry,density,options,image_info->filename,
     postscript_filename);
   ProgressMonitor(RenderPostscriptText,0,8);
@@ -332,7 +335,10 @@ Export Image *ReadPSImage(const ImageInfo *image_info)
         image_info->filename);
       return((Image *) NULL);
     }
-  image=ReadPNMImage(image_info);
+  local_info=CloneImageInfo(image_info);
+  GetBlobInfo(&local_info->blob);
+  image=ReadPNMImage(local_info);
+  DestroyImageInfo(local_info);
   (void) remove(image_info->filename);
   if (image == (Image *) NULL)
     {
@@ -648,6 +654,7 @@ Export unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
     };
 
   char
+    buffer[MaxTextExtent],
     date[MaxTextExtent],
     density[MaxTextExtent],
     **labels;
@@ -656,14 +663,12 @@ Export unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
     **q;
 
   double
-    x_scale,
-    y_scale;
-
-  float
     dx_resolution,
     dy_resolution,
     x_resolution,
-    y_resolution;
+    x_scale,
+    y_resolution,
+    y_scale;
 
   int
     length,
@@ -691,14 +696,15 @@ Export unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
     page,
     polarity,
     scene,
+    status,
     text_size,
     width;
 
   /*
     Open output image file.
   */
-  OpenImage(image_info,image,WriteBinaryType);
-  if (image->file == (FILE *) NULL)
+  status=OpenBlob(image_info,image,WriteBinaryType);
+  if (status == False)
     WriterExit(FileOpenWarning,"Unable to open file",image);
   page=1;
   scene=0;
@@ -730,12 +736,12 @@ Export unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
     dy_resolution=72.0;
     x_resolution=72.0;
     (void) strcpy(density,PSDensityGeometry);
-    count=sscanf(density,"%fx%f",&x_resolution,&y_resolution);
+    count=sscanf(density,"%lfx%lf",&x_resolution,&y_resolution);
     if (count != 2)
       y_resolution=x_resolution;
     if (image_info->density != (char *) NULL)
       {
-        count=sscanf(image_info->density,"%fx%f",&x_resolution,&y_resolution);
+        count=sscanf(image_info->density,"%lfx%lf",&x_resolution,&y_resolution);
         if (count != 2)
           y_resolution=x_resolution;
       }
@@ -749,32 +755,45 @@ Export unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
           Output Postscript header.
         */
         if (Latin1Compare(image_info->magick,"PS") == 0)
-          (void) fprintf(image->file,"%%!PS-Adobe-3.0\n");
+          (void) strcpy(buffer,"%!PS-Adobe-3.0\n");
         else
-          (void) fprintf(image->file,"%%!PS-Adobe-3.0 EPSF-3.0\n");
-        (void) fprintf(image->file,"%%%%Creator: (ImageMagick)\n");
-        (void) fprintf(image->file,"%%%%Title: (%.1024s)\n",image->filename);
+          (void) strcpy(buffer,"%!PS-Adobe-3.0 EPSF-3.0\n");
+        (void) WriteBlob(image,strlen(buffer),buffer);
+        (void) strcpy(buffer,"%%Creator: (ImageMagick)\n");
+        (void) WriteBlob(image,strlen(buffer),buffer);
+        (void) sprintf(buffer,"%%%%Title: (%.1024s)\n",image->filename);
+        (void) WriteBlob(image,strlen(buffer),buffer);
         timer=time((time_t *) NULL);
         (void) localtime(&timer);
         (void) strcpy(date,ctime(&timer));
         date[Extent(date)-1]='\0';
-        (void) fprintf(image->file,"%%%%CreationDate: (%.1024s)\n",date);
+        (void) sprintf(buffer,"%%%%CreationDate: (%.1024s)\n",date);
+        (void) WriteBlob(image,strlen(buffer),buffer);
         bounding_box.x1=x;
         bounding_box.y1=y;
         bounding_box.x2=x+x_scale-1;
         bounding_box.y2=y+(height+text_size)-1;
         if (image_info->adjoin && (image->next != (Image *) NULL))
-          (void) fprintf(image->file,"%%%%BoundingBox: (atend)\n");
+          (void) strcpy(buffer,"%%%%BoundingBox: (atend)\n");
         else
-          (void) fprintf(image->file,"%%%%BoundingBox: %g %g %g %g\n",
+          (void) sprintf(buffer,"%%%%BoundingBox: %g %g %g %g\n",
             bounding_box.x1,bounding_box.y1,bounding_box.x2,bounding_box.y2);
+        (void) WriteBlob(image,strlen(buffer),buffer);
         if (image->label != (char *) NULL)
-          (void) fprintf(image->file,
-            "%%%%DocumentNeededResources: font Helvetica\n");
-        (void) fprintf(image->file,"%%%%DocumentData: Clean7Bit\n");
-        (void) fprintf(image->file,"%%%%LanguageLevel: 1\n");
+          {
+            (void) strcpy(buffer,
+              "%%%%DocumentNeededResources: font Helvetica\n");
+            (void) WriteBlob(image,strlen(buffer),buffer);
+          }
+        (void) strcpy(buffer,"%%DocumentData: Clean7Bit\n");
+        (void) WriteBlob(image,strlen(buffer),buffer);
+        (void) strcpy(buffer,"%%LanguageLevel: 1\n");
+        (void) WriteBlob(image,strlen(buffer),buffer);
         if (Latin1Compare(image_info->magick,"PS") != 0)
-          (void) fprintf(image->file,"%%%%Pages: 0\n");
+          {
+            (void) strcpy(buffer,"%%Pages: 0\n");
+            (void) WriteBlob(image,strlen(buffer),buffer);
+          }
         else
           {
             Image
@@ -786,8 +805,10 @@ Export unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
             /*
               Compute the number of pages.
             */
-            (void) fprintf(image->file,"%%%%Orientation: Portrait\n");
-            (void) fprintf(image->file,"%%%%PageOrder: Ascend\n");
+            (void) strcpy(buffer,"%%Orientation: Portrait\n");
+            (void) WriteBlob(image,strlen(buffer),buffer);
+            (void) strcpy(buffer,"%%PageOrder: Ascend\n");
+            (void) WriteBlob(image,strlen(buffer),buffer);
             pages=1;
             if (image_info->adjoin)
               for (next_image=image->next; next_image != (Image *) NULL; )
@@ -795,12 +816,17 @@ Export unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
                 next_image=next_image->next;
                 pages++;
               }
-            (void) fprintf(image->file,"%%%%Pages: %u\n",pages);
+            (void) sprintf(buffer,"%%%%Pages: %u\n",pages);
+            (void) WriteBlob(image,strlen(buffer),buffer);
           }
-        (void) fprintf(image->file,"%%%%EndComments\n");
-        (void) fprintf(image->file,"\n%%%%BeginDefaults\n");
-        (void) fprintf(image->file,"%%%%PageOrientation: Portrait\n");
-        (void) fprintf(image->file,"%%%%EndDefaults\n\n");
+        (void) strcpy(buffer,"%%EndComments\n");
+        (void) WriteBlob(image,strlen(buffer),buffer);
+        (void) strcpy(buffer,"\n%%BeginDefaults\n");
+        (void) WriteBlob(image,strlen(buffer),buffer);
+        (void) strcpy(buffer,"%%PageOrientation: Portrait\n");
+        (void) WriteBlob(image,strlen(buffer),buffer);
+        (void) strcpy(buffer,"%%EndDefaults\n\n");
+        (void) WriteBlob(image,strlen(buffer),buffer);
         if ((Latin1Compare(image_info->magick,"EPI") == 0) ||
             (Latin1Compare(image_info->magick,"EPT") == 0) ||
             (Latin1Compare(image_info->magick,"EPSI") == 0))
@@ -841,9 +867,10 @@ Export unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
             count=0;
             x=0;
             p=preview_image->pixels;
-            (void) fprintf(image->file,"%%%%BeginPreview: %u %u %u %u\n%%  ",
+            (void) sprintf(buffer,"%%%%BeginPreview: %u %u %u %u\n%%  ",
               preview_image->columns,preview_image->rows,(unsigned int) 1,
               (((preview_image->columns+7) >> 3)*preview_image->rows+35)/36);
+            (void) WriteBlob(image,strlen(buffer),buffer);
             for (i=0; i < (int) preview_image->packets; i++)
             {
               for (j=0; j <= ((int) p->length); j++)
@@ -854,11 +881,13 @@ Export unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
                 bit++;
                 if (bit == 8)
                   {
-                    (void) fprintf(image->file,"%02x",byte & 0xff);
+                    (void) sprintf(buffer,"%02x",byte & 0xff);
+                    (void) WriteBlob(image,strlen(buffer),buffer);
                     count++;
                     if (count == 36)
                       {
-                        (void) fprintf(image->file,"\n%%  ");
+                        (void) strcpy(buffer,"\n%%  ");
+                        (void) WriteBlob(image,strlen(buffer),buffer);
                         count=0;
                       };
                     bit=0;
@@ -870,11 +899,13 @@ Export unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
                     if (bit != 0)
                       {
                         byte<<=(8-bit);
-                        (void) fprintf(image->file,"%02x",byte & 0xff);
+                        (void) sprintf(buffer,"%02x",byte & 0xff);
+                        (void) WriteBlob(image,strlen(buffer),buffer);
                         count++;
                         if (count == 36)
                           {
-                            (void) fprintf(image->file,"\n%%  ");
+                            (void) strcpy(buffer,"\n%%  ");
+                            (void) WriteBlob(image,strlen(buffer),buffer);
                             count=0;
                           };
                         bit=0;
@@ -885,31 +916,48 @@ Export unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
                 }
                 p++;
               }
-              (void) fprintf(image->file,"\n%%%%EndPreview\n");
+              (void) strcpy(buffer,"\n%%EndPreview\n");
+              (void) WriteBlob(image,strlen(buffer),buffer);
               DestroyImage(preview_image);
             }
         /*
           Output Postscript commands.
         */
         for (q=PostscriptProlog; *q; q++)
-          (void) fprintf(image->file,"%.255s\n",*q);
+        {
+          (void) sprintf(buffer,"%.255s\n",*q);
+          (void) WriteBlob(image,strlen(buffer),buffer);
+        }
         for (i=MultilineCensus(image->label)-1; i >= 0; i--)
         {
-          (void) fprintf(image->file,"  /label 512 string def\n");
-          (void) fprintf(image->file,"  currentfile label readline pop\n");
-          (void) fprintf(image->file,"  0 y %d add moveto label show pop\n",
+          (void) strcpy(buffer,"  /label 512 string def\n");
+          (void) WriteBlob(image,strlen(buffer),buffer);
+          (void) strcpy(buffer,"  currentfile label readline pop\n");
+          (void) WriteBlob(image,strlen(buffer),buffer);
+          (void) sprintf(buffer,"  0 y %d add moveto label show pop\n",
             i*image_info->pointsize+12);
+          (void) WriteBlob(image,strlen(buffer),buffer);
         }
         for (q=PostscriptEpilog; *q; q++)
-          (void) fprintf(image->file,"%.255s\n",*q);
+        {
+          (void) sprintf(buffer,"%.255s\n",*q);
+          (void) WriteBlob(image,strlen(buffer),buffer);
+        }
         if (Latin1Compare(image_info->magick,"PS") == 0)
-          (void) fprintf(image->file,"  showpage\n");
-        (void) fprintf(image->file,"} bind def\n");
-        (void) fprintf(image->file,"%%%%EndProlog\n");
+          {
+            (void) strcpy(buffer,"  showpage\n");
+            (void) WriteBlob(image,strlen(buffer),buffer);
+          }
+        (void) strcpy(buffer,"} bind def\n");
+        (void) WriteBlob(image,strlen(buffer),buffer);
+        (void) strcpy(buffer,"%%EndProlog\n");
+        (void) WriteBlob(image,strlen(buffer),buffer);
       }
-    (void) fprintf(image->file,"%%%%Page:  1 %u\n",page++);
-    (void) fprintf(image->file,"%%%%PageBoundingBox: %d %d %d %d\n",x,y,
+    (void) sprintf(buffer,"%%%%Page:  1 %u\n",page++);
+    (void) WriteBlob(image,strlen(buffer),buffer);
+    (void) sprintf(buffer,"%%%%PageBoundingBox: %d %d %d %d\n",x,y,
       x+(int) width,y+(int) (height+text_size));
+    (void) WriteBlob(image,strlen(buffer),buffer);
     if (x < bounding_box.x1)
       bounding_box.x1=x;
     if (y < bounding_box.y1)
@@ -919,22 +967,32 @@ Export unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
     if ((y+(int) (height+text_size)-1) > bounding_box.y2)
       bounding_box.y2=y+(height+text_size)-1;
     if (image->label != (char *) NULL)
-      (void) fprintf(image->file,"%%%%PageResources: font Helvetica\n");
+      {
+        (void) strcpy(buffer,"%%%%PageResources: font Helvetica\n");
+        (void) WriteBlob(image,strlen(buffer),buffer);
+      }
     if (Latin1Compare(image_info->magick,"PS") != 0)
-      (void) fprintf(image->file,"userdict begin\n");
-    (void) fprintf(image->file,"%%%%BeginData:\n");
-    (void) fprintf(image->file,"DisplayImage\n");
+      {
+        (void) strcpy(buffer,"userdict begin\n");
+        (void) WriteBlob(image,strlen(buffer),buffer);
+      }
+    (void) strcpy(buffer,"%%BeginData:\n");
+    (void) WriteBlob(image,strlen(buffer),buffer);
+    (void) strcpy(buffer,"DisplayImage\n");
+    (void) WriteBlob(image,strlen(buffer),buffer);
     /*
       Output image data.
     */
     labels=StringToList(image->label);
-    (void) fprintf(image->file,"%d %d\n%f %f\n%u\n",x,y,x_scale,y_scale,
+    (void) sprintf(buffer,"%d %d\n%g %g\n%u\n",x,y,x_scale,y_scale,
       image_info->pointsize);
+    (void) WriteBlob(image,strlen(buffer),buffer);
     if (labels != (char **) NULL)
       {
         for (i=0; labels[i] != (char *) NULL; i++)
         {
-          (void) fprintf(image->file,"%.1024s \n",labels[i]);
+          (void) sprintf(buffer,"%.1024s \n",labels[i]);
+          (void) WriteBlob(image,strlen(buffer),buffer);
           FreeMemory(labels[i]);
         }
         FreeMemory(labels);
@@ -946,9 +1004,10 @@ Export unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
         /*
           Dump DirectClass image.
         */
-        (void) fprintf(image->file,"%u %u\n%d\n%d\n",
+        (void) sprintf(buffer,"%u %u\n%d\n%d\n",
           image->columns,image->rows,(int) (image->class == PseudoClass),
           (int) (image_info->compression == NoCompression));
+        (void) WriteBlob(image,strlen(buffer),buffer);
         switch (image_info->compression)
         {
           case RunlengthEncodedCompression:
@@ -962,17 +1021,18 @@ Export unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
               for (length=p->length; length >= 0; length-=256)
               {
                 if (image->matte && (p->index == Transparent))
-                  (void) fprintf(image->file,"ffffff%02x",(unsigned int)
+                  (void) sprintf(buffer,"ffffff%02x",(unsigned int)
                     Min(length,0xff));
                 else
-                  (void) fprintf(image->file,"%02lx%02lx%02lx%02lx",
+                  (void) sprintf(buffer,"%02lx%02lx%02lx%02lx",
                     DownScale(p->red),DownScale(p->green),DownScale(p->blue),
                     (unsigned long) Min(length,0xff));
+                (void) WriteBlob(image,strlen(buffer),buffer);
                 x++;
                 if (x == 9)
                   {
                     x=0;
-                    (void) fprintf(image->file,"\n");
+                    (void) strcpy(buffer,"\n");
                   }
               }
               p++;
@@ -992,15 +1052,16 @@ Export unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
               for (j=0; j <= ((int) p->length); j++)
               {
                 if (image->matte && (p->index == Transparent))
-                  (void) fprintf(image->file,"ffffff");
+                  (void) strcpy(buffer,"ffffff");
                 else
-                  (void) fprintf(image->file,"%02lx%02lx%02lx",
+                  (void) sprintf(buffer,"%02lx%02lx%02lx",
                     DownScale(p->red),DownScale(p->green),DownScale(p->blue));
+                (void) WriteBlob(image,strlen(buffer),buffer);
                 x++;
                 if (x == 12)
                   {
                     x=0;
-                    (void) fprintf(image->file,"\n");
+                    (void) WriteByte(image,'\n');
                   }
               }
               p++;
@@ -1011,13 +1072,14 @@ Export unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
             break;
           }
         }
-        (void) fprintf(image->file,"\n");
+        (void) strcpy(buffer,"\n");
       }
     else
       if (IsGrayImage(image))
         {
-          (void) fprintf(image->file,"%u %u\n1\n1\n1\n%d\n",
+          (void) sprintf(buffer,"%u %u\n1\n1\n1\n%d\n",
             image->columns,image->rows,IsMonochromeImage(image) ? 1 : 8);
+          (void) WriteBlob(image,strlen(buffer),buffer);
           if (!IsMonochromeImage(image))
             {
               /*
@@ -1027,12 +1089,13 @@ Export unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
               {
                 for (j=0; j <= ((int) p->length); j++)
                 {
-                  (void) fprintf(image->file,"%02lx",DownScale(p->red));
+                  (void) sprintf(buffer,"%02lx",Intensity(*p));
+                  (void) WriteBlob(image,strlen(buffer),buffer);
                   x++;
                   if (x == 36)
                     {
                       x=0;
-                      (void) fprintf(image->file,"\n");
+                      (void) WriteByte(image,'\n');
                     }
                 }
                 p++;
@@ -1067,11 +1130,12 @@ Export unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
                   bit++;
                   if (bit == 8)
                     {
-                      (void) fprintf(image->file,"%02x",byte & 0xff);
+                      (void) sprintf(buffer,"%02x",byte & 0xff);
+                      (void) WriteBlob(image,strlen(buffer),buffer);
                       count++;
                       if (count == 36)
                         {
-                          (void) fprintf(image->file,"\n");
+                          (void) WriteByte(image,'\n');
                           count=0;
                         };
                       bit=0;
@@ -1086,11 +1150,12 @@ Export unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
                       if (bit != 0)
                         {
                           byte<<=(8-bit);
-                          (void) fprintf(image->file,"%02x",byte & 0xff);
+                          (void) sprintf(buffer,"%02x",byte & 0xff);
+                          (void) WriteBlob(image,strlen(buffer),buffer);
                           count++;
                           if (count == 36)
                             {
-                              (void) fprintf(image->file,"\n");
+                              (void) WriteByte(image,'\n');
                               count=0;
                             };
                         };
@@ -1107,25 +1172,30 @@ Export unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
               }
             }
           if (count != 0)
-            (void) fprintf(image->file,"\n");
+            (void) WriteByte(image,'\n');
         }
       else
         {
           /*
             Dump PseudoClass image.
           */
-          (void) fprintf(image->file,"%u %u\n%d\n%d\n0\n",
+          (void) sprintf(buffer,"%u %u\n%d\n%d\n0\n",
             image->columns,image->rows,(int) (image->class == PseudoClass),
             (int) (image_info->compression == NoCompression));
+          (void) WriteBlob(image,strlen(buffer),buffer);
           /*
             Dump number of colors and colormap.
           */
-          (void) fprintf(image->file,"%u\n",image->colors);
+          (void) sprintf(buffer,"%u\n",image->colors);
+          (void) WriteBlob(image,strlen(buffer),buffer);
           for (i=0; i < (int) image->colors; i++)
-            (void) fprintf(image->file,"%02lx%02lx%02lx\n",
+          {
+            (void) sprintf(buffer,"%02lx%02lx%02lx\n",
               DownScale(image->colormap[i].red),
               DownScale(image->colormap[i].green),
               DownScale(image->colormap[i].blue));
+            (void) WriteBlob(image,strlen(buffer),buffer);
+          }
           switch (image_info->compression)
           {
             case RunlengthEncodedCompression:
@@ -1138,13 +1208,14 @@ Export unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
               {
                 for (length=p->length; length >= 0; length-=256)
                 {
-                  (void) fprintf(image->file,"%02x%02x",(unsigned int) p->index,
+                  (void) sprintf(buffer,"%02x%02x",(unsigned int) p->index,
                     (unsigned int) Min(length,0xff));
+                  (void) WriteBlob(image,strlen(buffer),buffer);
                   x++;
                   if (x == 18)
                     {
                       x=0;
-                      (void) fprintf(image->file,"\n");
+                      (void) WriteByte(image,'\n');
                     }
                 }
                 p++;
@@ -1163,12 +1234,13 @@ Export unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
               {
                 for (j=0; j <= ((int) p->length); j++)
                 {
-                  (void) fprintf(image->file,"%02x",(unsigned int) p->index);
+                  (void) sprintf(buffer,"%02x",(unsigned int) p->index);
+                  (void) WriteBlob(image,strlen(buffer),buffer);
                   x++;
                   if (x == 36)
                     {
                       x=0;
-                      (void) fprintf(image->file,"\n");
+                      (void) WriteByte(image,'\n');
                     }
                 }
                 p++;
@@ -1179,12 +1251,17 @@ Export unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
               break;
             }
           }
-          (void) fprintf(image->file,"\n");
+          (void) WriteByte(image,'\n');
         }
-    (void) fprintf(image->file,"%%%%EndData\n");
+    (void) strcpy(buffer,"%%EndData\n");
+    (void) WriteBlob(image,strlen(buffer),buffer);
     if (Latin1Compare(image_info->magick,"PS") != 0)
-      (void) fprintf(image->file,"end\n");
-    (void) fprintf(image->file,"%%%%PageTrailer\n");
+      {
+        (void) strcpy(buffer,"end\n");
+        (void) WriteBlob(image,strlen(buffer),buffer);
+      }
+    (void) strcpy(buffer,"%%PageTrailer\n");
+    (void) WriteBlob(image,strlen(buffer),buffer);
     if (image->next == (Image *) NULL)
       break;
     image->next->file=image->file;
@@ -1194,11 +1271,16 @@ Export unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
   if (image_info->adjoin)
     while (image->previous != (Image *) NULL)
       image=image->previous;
-  (void) fprintf(image->file,"%%%%Trailer\n");
+  (void) strcpy(buffer,"%%Trailer\n");
+  (void) WriteBlob(image,strlen(buffer),buffer);
   if (page > 1)
-    (void) fprintf(image->file,"%%%%BoundingBox: %g %g %g %g\n",
-      bounding_box.x1,bounding_box.y1,bounding_box.x2,bounding_box.y2);
-  (void) fprintf(image->file,"%%%%EOF\n");
-  CloseImage(image);
+    {
+      (void) sprintf(buffer,"%%%%BoundingBox: %g %g %g %g\n",
+        bounding_box.x1,bounding_box.y1,bounding_box.x2,bounding_box.y2);
+      (void) WriteBlob(image,strlen(buffer),buffer);
+    }
+  (void) strcpy(buffer,"%%EOF\n");
+  (void) WriteBlob(image,strlen(buffer),buffer);
+  CloseBlob(image);
   return(True);
 }
