@@ -551,7 +551,7 @@ static unsigned int Classification(CubeInfo *cube_info,const Image *image)
   for (i=1; i <= MaxTreeDepth; i++)
     bisect[i]=0.5*bisect[i-1];
   squares=cube_info->squares;
-  cube_info->root->quantization_error=
+  cube_info->root->quantization_error+=
     3.0*(MaxRGB/2.0)*(MaxRGB/2.0)*image->columns*image->rows;
   p=image->pixels;
   for (i=0; i < (int) image->packets; i++)
@@ -644,7 +644,7 @@ static unsigned int Classification(CubeInfo *cube_info,const Image *image)
 %  A description of each parameter follows:
 %
 %    o cloned_info: Method CloneQuantizeInfo returns a duplicate of the given
-%      image info, or if image info is NULL a new one.
+%      quantize info, or if image info is NULL a new one.
 %
 %    o quantize_info: a structure of type info.
 %
@@ -2021,15 +2021,12 @@ Export unsigned int QuantizeImage(const QuantizeInfo *quantize_info,
 %
 %  The format of the QuantizeImages routine is:
 %
-%      status=QuantizeImages(quantize_info,number_images,images)
+%      status=QuantizeImages(quantize_info,images)
 %
 %  A description of each parameter follows:
 %
 %    o quantize_info: Specifies a pointer to an QuantizeInfo structure.
 %
-%    o number_images:  Specifies an unsigned integer representing the number
-%      images in the image set.
-%
 %    o images: Specifies a pointer to a list of Image structures.
 %
 %
