@@ -106,7 +106,8 @@ Export Image *ReadRGBImage(const ImageInfo *image_info)
     *scanline;
 
   unsigned int
-    packet_size;
+    packet_size,
+    status;
 
   unsigned short
     value;
@@ -124,11 +125,11 @@ Export Image *ReadRGBImage(const ImageInfo *image_info)
       /*
         Open image file.
       */
-      OpenImage(image_info,image,ReadBinaryType);
-      if (image->file == (FILE *) NULL)
+      status=OpenBlob(image_info,image,ReadBinaryType);
+      if (status == False)
         ReaderExit(FileOpenWarning,"Unable to open file",image);
       for (i=0; i < image->offset; i++)
-        (void) fgetc(image->file);
+        (void) ReadByte(image);
     }
   /*
     Allocate memory for a scanline.
@@ -151,8 +152,8 @@ Export Image *ReadRGBImage(const ImageInfo *image_info)
       */
       image->scene++;
       for (y=0; y < (int) image->rows; y++)
-        (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-          image->file);
+        (void) ReadBlob(image,packet_size*image->tile_info.width,
+          (char *) scanline);
     }
   do
   {
@@ -177,14 +178,14 @@ Export Image *ReadRGBImage(const ImageInfo *image_info)
           No interlacing:  RGBRGBRGBRGBRGBRGB...
         */
         for (y=0; y < image->tile_info.y; y++)
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
         q=image->pixels;
         for (y=0; y < (int) image->rows; y++)
         {
           if ((y > 0) || (image->previous == (Image *) NULL))
-            (void) ReadData((char *) scanline,packet_size,
-              image->tile_info.width,image->file);
+            (void) ReadBlob(image,packet_size*image->tile_info.width,
+              (char *) scanline);
           p=scanline+packet_size*image->tile_info.x;
           for (x=0; x < (int) image->columns; x++)
           {
@@ -203,8 +204,8 @@ Export Image *ReadRGBImage(const ImageInfo *image_info)
         }
         count=image->tile_info.height-image->rows-image->tile_info.y;
         for (y=0; y < count; y++)
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
         break;
       }
       case LineInterlace:
@@ -214,13 +215,13 @@ Export Image *ReadRGBImage(const ImageInfo *image_info)
         */
         packet_size=image->depth >> 3;
         for (y=0; y < image->tile_info.y; y++)
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
         for (y=0; y < (int) image->rows; y++)
         {
           if ((y > 0) || (image->previous == (Image *) NULL))
-            (void) ReadData((char *) scanline,packet_size,
-              image->tile_info.width,image->file);
+            (void) ReadBlob(image,packet_size*image->tile_info.width,
+              (char *) scanline);
           p=scanline+packet_size*image->tile_info.x;
           q=image->pixels+y*image->columns;
           for (x=0; x < (int) image->columns; x++)
@@ -230,8 +231,8 @@ Export Image *ReadRGBImage(const ImageInfo *image_info)
             q->length=0;
             q++;
           }
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
           p=scanline+packet_size*image->tile_info.x;
           q=image->pixels+y*image->columns;
           for (x=0; x < (int) image->columns; x++)
@@ -239,8 +240,8 @@ Export Image *ReadRGBImage(const ImageInfo *image_info)
             ReadQuantum(q->green,p);
             q++;
           }
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
           p=scanline+packet_size*image->tile_info.x;
           q=image->pixels+y*image->columns;
           for (x=0; x < (int) image->columns; x++)
@@ -250,8 +251,8 @@ Export Image *ReadRGBImage(const ImageInfo *image_info)
           }
           if (image->matte)
             {
-              (void) ReadData((char *) scanline,packet_size,
-                image->tile_info.width,image->file);
+              (void) ReadBlob(image,packet_size*image->tile_info.width,
+                (char *) scanline);
               p=scanline+packet_size*image->tile_info.x;
               q=image->pixels+y*image->columns;
               for (x=0; x < (int) image->columns; x++)
@@ -266,8 +267,8 @@ Export Image *ReadRGBImage(const ImageInfo *image_info)
         }
         count=image->tile_info.height-image->rows-image->tile_info.y;
         for (y=0; y < count; y++)
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
         break;
       }
       case PlaneInterlace:
@@ -282,22 +283,22 @@ Export Image *ReadRGBImage(const ImageInfo *image_info)
         if (image_info->interlace == PartitionInterlace)
           {
             AppendImageFormat("R",image->filename);
-            OpenImage(image_info,image,ReadBinaryType);
-            if (image->file == (FILE *) NULL)
+            status=OpenBlob(image_info,image,ReadBinaryType);
+            if (status == False)
               ReaderExit(FileOpenWarning,"Unable to open file",image);
           }
         packet_size=image->depth >> 3;
         for (y=0; y < image->tile_info.y; y++)
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
         i=0;
         span=image->rows*(image->matte ? 4 : 3);
         q=image->pixels;
         for (y=0; y < (int) image->rows; y++)
         {
           if ((y > 0) || (image->previous == (Image *) NULL))
-            (void) ReadData((char *) scanline,packet_size,
-              image->tile_info.width,image->file);
+            (void) ReadBlob(image,packet_size*image->tile_info.width,
+              (char *) scanline);
           p=scanline+packet_size*image->tile_info.x;
           for (x=0; x < (int) image->columns; x++)
           {
@@ -313,24 +314,24 @@ Export Image *ReadRGBImage(const ImageInfo *image_info)
         }
         count=image->tile_info.height-image->rows-image->tile_info.y;
         for (y=0; y < count; y++)
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
         if (image_info->interlace == PartitionInterlace)
           {
-            CloseImage(image);
+            CloseBlob(image);
             AppendImageFormat("G",image->filename);
-            OpenImage(image_info,image,ReadBinaryType);
-            if (image->file == (FILE *) NULL)
+            status=OpenBlob(image_info,image,ReadBinaryType);
+            if (status == False)
               ReaderExit(FileOpenWarning,"Unable to open file",image);
           }
         q=image->pixels;
         for (y=0; y < image->tile_info.y; y++)
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
         for (y=0; y < (int) image->rows; y++)
         {
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
           p=scanline+packet_size*image->tile_info.x;
           for (x=0; x < (int) image->columns; x++)
           {
@@ -344,24 +345,24 @@ Export Image *ReadRGBImage(const ImageInfo *image_info)
         }
         count=image->tile_info.height-image->rows-image->tile_info.y;
         for (y=0; y < count; y++)
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
         if (image_info->interlace == PartitionInterlace)
           {
-            CloseImage(image);
+            CloseBlob(image);
             AppendImageFormat("B",image->filename);
-            OpenImage(image_info,image,ReadBinaryType);
-            if (image->file == (FILE *) NULL)
+            status=OpenBlob(image_info,image,ReadBinaryType);
+            if (status == False)
               ReaderExit(FileOpenWarning,"Unable to open file",image);
           }
         q=image->pixels;
         for (y=0; y < image->tile_info.y; y++)
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
         for (y=0; y < (int) image->rows; y++)
         {
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
           p=scanline+packet_size*image->tile_info.x;
           for (x=0; x < (int) image->columns; x++)
           {
@@ -375,8 +376,8 @@ Export Image *ReadRGBImage(const ImageInfo *image_info)
         }
         count=image->tile_info.height-image->rows-image->tile_info.y;
         for (y=0; y < count; y++)
-          (void) ReadData((char *) scanline,packet_size,image->tile_info.width,
-            image->file);
+          (void) ReadBlob(image,packet_size*image->tile_info.width,
+            (char *) scanline);
         if (image->matte)
           {
             /*
@@ -384,20 +385,20 @@ Export Image *ReadRGBImage(const ImageInfo *image_info)
             */
             if (image_info->interlace == PartitionInterlace)
               {
-                CloseImage(image);
+                CloseBlob(image);
                 AppendImageFormat("A",image->filename);
-                OpenImage(image_info,image,ReadBinaryType);
-                if (image->file == (FILE *) NULL)
+                status=OpenBlob(image_info,image,ReadBinaryType);
+                if (status == False)
                   ReaderExit(FileOpenWarning,"Unable to open file",image);
               }
             q=image->pixels;
             for (y=0; y < image->tile_info.y; y++)
-              (void) ReadData((char *) scanline,packet_size,
-                image->tile_info.width,image->file);
+              (void) ReadBlob(image,packet_size*image->tile_info.width,
+                (char *) scanline);
             for (y=0; y < (int) image->rows; y++)
             {
-              (void) ReadData((char *) scanline,packet_size,
-                image->tile_info.width,image->file);
+              (void) ReadBlob(image,packet_size*image->tile_info.width,
+                (char *) scanline);
               p=scanline+packet_size*image->tile_info.x;
               for (x=0; x < (int) image->columns; x++)
               {
@@ -411,8 +412,8 @@ Export Image *ReadRGBImage(const ImageInfo *image_info)
             }
             count=image->tile_info.height-image->rows-image->tile_info.y;
             for (y=0; y < count; y++)
-              (void) ReadData((char *) scanline,packet_size,
-                image->tile_info.width,image->file);
+              (void) ReadBlob(image,packet_size*image->tile_info.width,
+                (char *) scanline);
           }
         if (image_info->interlace == PartitionInterlace)
           (void) strcpy(image->filename,image_info->filename);
@@ -420,7 +421,7 @@ Export Image *ReadRGBImage(const ImageInfo *image_info)
       }
     }
     CondenseImage(image);
-    if (feof(image->file))
+    if (EOFBlob(image))
       MagickWarning(CorruptImageWarning,"not enough pixels",image->filename);
     /*
       Proceed to next image.
@@ -428,7 +429,7 @@ Export Image *ReadRGBImage(const ImageInfo *image_info)
     if (image_info->subrange != 0)
       if (image->scene >= (image_info->subimage+image_info->subrange-1))
         break;
-    count=ReadData((char *) scanline,packet_size,image->columns,image->file);
+    count=ReadBlob(image,packet_size*image->tile_info.width,(char *) scanline);
     if (count > 0)
       {
         /*
@@ -441,14 +442,14 @@ Export Image *ReadRGBImage(const ImageInfo *image_info)
             return((Image *) NULL);
           }
         image=image->next;
-        ProgressMonitor(LoadImagesText,(unsigned int) ftell(image->file),
+        ProgressMonitor(LoadImagesText,(unsigned int) TellBlob(image),
           (unsigned int) image->filesize);
       }
   } while (count > 0);
   FreeMemory((char *) scanline);
   while (image->previous != (Image *) NULL)
     image=image->previous;
-  CloseImage(image);
+  CloseBlob(image);
   return(image);
 }
 
@@ -496,7 +497,8 @@ Export unsigned int WriteRGBImage(const ImageInfo *image_info,Image *image)
     *p;
 
   unsigned int
-    scene;
+    scene,
+    status;
 
   image->depth=QuantumDepth;
   if (image_info->interlace != PartitionInterlace)
@@ -504,8 +506,8 @@ Export unsigned int WriteRGBImage(const ImageInfo *image_info,Image *image)
       /*
         Open output image file.
       */
-      OpenImage(image_info,image,WriteBinaryType);
-      if (image->file == (FILE *) NULL)
+      status=OpenBlob(image_info,image,WriteBinaryType);
+      if (status == False)
         WriterExit(FileOpenWarning,"Unable to open file",image);
     }
   scene=0;
@@ -555,7 +557,7 @@ Export unsigned int WriteRGBImage(const ImageInfo *image_info,Image *image)
             x++;
             if (x == (int) image->columns)
               {
-                (void) fwrite((char *) pixels,1,q-pixels,image->file);
+                (void) WriteBlob(image,q-pixels,(char *) pixels);
                 if (image->previous == (Image *) NULL)
                   if (QuantumTick(y,image->rows))
                     ProgressMonitor(SaveImageText,y,image->rows);
@@ -617,8 +619,8 @@ Export unsigned int WriteRGBImage(const ImageInfo *image_info,Image *image)
         if (image_info->interlace == PartitionInterlace)
           {
             AppendImageFormat("R",image->filename);
-            OpenImage(image_info,image,WriteBinaryType);
-            if (image->file == (FILE *) NULL)
+            status=OpenBlob(image_info,image,WriteBinaryType);
+            if (status == False)
               WriterExit(FileOpenWarning,"Unable to open file",image);
           }
         p=image->pixels;
@@ -630,10 +632,10 @@ Export unsigned int WriteRGBImage(const ImageInfo *image_info,Image *image)
         }
         if (image_info->interlace == PartitionInterlace)
           {
-            CloseImage(image);
+            CloseBlob(image);
             AppendImageFormat("G",image->filename);
-            OpenImage(image_info,image,WriteBinaryType);
-            if (image->file == (FILE *) NULL)
+            status=OpenBlob(image_info,image,WriteBinaryType);
+            if (status == False)
               WriterExit(FileOpenWarning,"Unable to open file",image);
           }
         ProgressMonitor(SaveImageText,100,400);
@@ -646,10 +648,10 @@ Export unsigned int WriteRGBImage(const ImageInfo *image_info,Image *image)
         }
         if (image_info->interlace == PartitionInterlace)
           {
-            CloseImage(image);
+            CloseBlob(image);
             AppendImageFormat("B",image->filename);
-            OpenImage(image_info,image,WriteBinaryType);
-            if (image->file == (FILE *) NULL)
+            status=OpenBlob(image_info,image,WriteBinaryType);
+            if (status == False)
               WriterExit(FileOpenWarning,"Unable to open file",image);
           }
         ProgressMonitor(SaveImageText,200,400);
@@ -666,10 +668,10 @@ Export unsigned int WriteRGBImage(const ImageInfo *image_info,Image *image)
             p=image->pixels;
             if (image_info->interlace == PartitionInterlace)
               {
-                CloseImage(image);
+                CloseBlob(image);
                 AppendImageFormat("A",image->filename);
-                OpenImage(image_info,image,WriteBinaryType);
-                if (image->file == (FILE *) NULL)
+                status=OpenBlob(image_info,image,WriteBinaryType);
+                if (status == False)
                   WriterExit(FileOpenWarning,"Unable to open file",image);
               }
             for (i=0; i < (int) image->packets; i++)
@@ -694,6 +696,6 @@ Export unsigned int WriteRGBImage(const ImageInfo *image_info,Image *image)
   if (image_info->adjoin)
     while (image->previous != (Image *) NULL)
       image=image->previous;
-  CloseImage(image);
+  CloseBlob(image);
   return(True);
 }
