@@ -225,7 +225,9 @@ Export Image *ReadTIFFImage(const ImageInfo *image_info)
     *text;
 
   float
-    *chromaticity;
+    *chromaticity,
+    x_resolution,
+    y_resolution;
 
   Image
     *image;
@@ -284,6 +286,7 @@ Export Image *ReadTIFFImage(const ImageInfo *image_info)
     pages,
     photometric,
     samples_per_pixel,
+    sans,
     units,
     value;
 
@@ -296,8 +299,8 @@ Export Image *ReadTIFFImage(const ImageInfo *image_info)
   /*
     Open image.
   */
-  OpenImage(image_info,image,ReadBinaryType);
-  if (image->file == (FILE *) NULL)
+  status=OpenBlob(image_info,image,ReadBinaryType);
+  if (status == False)
     ReaderExit(FileOpenWarning,"Unable to open file",image);
   if ((image->file == stdin) || image->pipe)
     {
@@ -314,17 +317,17 @@ Export Image *ReadTIFFImage(const ImageInfo *image_info)
       file=fopen(image_info->filename,WriteBinaryType);
       if (file == (FILE *) NULL)
         ReaderExit(FileOpenWarning,"Unable to write file",image);
-      c=fgetc(image->file);
+      c=ReadByte(image);
       while (c != EOF)
       {
         (void) putc(c,file);
-        c=fgetc(image->file);
+        c=ReadByte(image);
       }
       (void) fclose(file);
       (void) strcpy(image->filename,image_info->filename);
       image->temporary=True;
     }
-  CloseImage(image);
+  CloseBlob(image);
   TIFFSetErrorHandler(TIFFWarningHandler);
   TIFFSetWarningHandler(TIFFWarningHandler);
   tiff=TIFFOpen(image->filename,ReadBinaryUnbufferedType);
@@ -357,8 +360,10 @@ Export Image *ReadTIFFImage(const ImageInfo *image_info)
       image->colorspace=CMYKColorspace;
     TIFFGetFieldDefaulted(tiff,TIFFTAG_SAMPLESPERPIXEL,&samples_per_pixel);
     TIFFGetFieldDefaulted(tiff,TIFFTAG_RESOLUTIONUNIT,&units);
-    TIFFGetFieldDefaulted(tiff,TIFFTAG_XRESOLUTION,&image->x_resolution);
-    TIFFGetFieldDefaulted(tiff,TIFFTAG_YRESOLUTION,&image->y_resolution);
+    TIFFGetFieldDefaulted(tiff,TIFFTAG_XRESOLUTION,&x_resolution);
+    TIFFGetFieldDefaulted(tiff,TIFFTAG_YRESOLUTION,&y_resolution);
+    image->x_resolution=x_resolution;
+    image->y_resolution=y_resolution;
     chromaticity=(float *) NULL;
     TIFFGetField(tiff,TIFFTAG_WHITEPOINT,&chromaticity);
     if (chromaticity != (float *) NULL)
@@ -429,7 +434,7 @@ Export Image *ReadTIFFImage(const ImageInfo *image_info)
     if (image_info->ping)
       {
         TIFFClose(tiff);
-        CloseImage(image);
+        CloseBlob(image);
         return(image);
       }
     if (units == RESUNIT_INCH)
@@ -440,9 +445,11 @@ Export Image *ReadTIFFImage(const ImageInfo *image_info)
     if (bits_per_sample < 8)
       image->depth=8;
     packets=0;
-    max_packets=Max((image->columns*image->rows+4) >> 3,1);
+    max_packets=image->columns*image->rows;
+    if (samples_per_pixel == 1)
+      max_packets=Max((image->columns*image->rows+1) >> 1,1);
     if (bits_per_sample == 1)
-      max_packets=Max((image->columns*image->rows+8) >> 4,1);
+      max_packets=Max((image->columns*image->rows+2) >> 2,1);
     image->pixels=(RunlengthPacket *)
       AllocateMemory(max_packets*sizeof(RunlengthPacket));
     if (image->pixels == (RunlengthPacket *) NULL)
@@ -493,7 +500,7 @@ Export Image *ReadTIFFImage(const ImageInfo *image_info)
         image->colormap=(ColorPacket *)
           AllocateMemory(image->colors*sizeof(ColorPacket));
         quantum_scanline=(Quantum *) AllocateMemory(width*sizeof(Quantum));
-        scanline=(unsigned char *) AllocateMemory(TIFFScanlineSize(tiff)+4);
+        scanline=(unsigned char *) AllocateMemory(2*TIFFScanlineSize(tiff)+4);
         if ((image->colormap == (ColorPacket *) NULL) ||
             (quantum_scanline == (Quantum *) NULL) ||
             (scanline == (unsigned char *) NULL))
@@ -571,6 +578,19 @@ Export Image *ReadTIFFImage(const ImageInfo *image_info)
         for (y=0; y < (int) image->rows; y++)
         {
           TIFFReadScanline(tiff,(char *) scanline,y,0);
+          if (bits_per_sample == 16)
+            {
+              unsigned long
+                lsb_first;
+
+              /*
+                Ensure the header byte-order is most-significant byte first.
+              */
+              lsb_first=1;
+              if (*(char *) &lsb_first)
+                MSBFirstOrderShort((char *) scanline,
+                  (TIFFScanlineSize(tiff) << 1)+4);
+            }
           p=scanline;
           r=quantum_scanline;
           switch (bits_per_sample)
@@ -688,8 +708,7 @@ Export Image *ReadTIFFImage(const ImageInfo *image_info)
         /*
           Convert TIFF image to DirectClass MIFF image.
         */
-        scanline=(unsigned char *)
-          AllocateMemory((TIFFScanlineSize(tiff) << 1)+4);
+        scanline=(unsigned char *) AllocateMemory(2*TIFFScanlineSize(tiff)+4);
         if (scanline == (unsigned char *) NULL)
           {
             TIFFClose(tiff);
@@ -698,7 +717,8 @@ Export Image *ReadTIFFImage(const ImageInfo *image_info)
           }
         TIFFGetFieldDefaulted(tiff,TIFFTAG_EXTRASAMPLES,&extra_samples,
           &sample_info);
-        image->matte=extra_samples == 1;
+        if (image->colorspace != CMYKColorspace)
+          image->matte=extra_samples == 1;
         for (y=0; y < (int) image->rows; y++)
         {
           TIFFReadScanline(tiff,(char *) scanline,y,0);
@@ -737,8 +757,10 @@ Export Image *ReadTIFFImage(const ImageInfo *image_info)
             ReadQuantum(green,p);
             ReadQuantum(blue,p);
             index=0;
-            if (samples_per_pixel == 4)
+            if (samples_per_pixel > 3)
               ReadQuantum(index,p);
+            for (i=4; i < samples_per_pixel; i++)
+              ReadQuantum(sans,p);
             if ((red == q->red) && (green == q->green) && (blue == q->blue) &&
                 (index == q->index) && ((int) q->length < MaxRunlength))
               q->length++;
@@ -1103,7 +1125,11 @@ Export unsigned int WriteTIFFImage(const ImageInfo *image_info,Image *image)
     *scanline;
 
   unsigned int
-    scene;
+    scene,
+    status;
+
+  unsigned long
+    strip_size;
 
   unsigned short
     value;
@@ -1160,8 +1186,8 @@ Export unsigned int WriteTIFFImage(const ImageInfo *image_info,Image *image)
   /*
     Open TIFF file.
   */
-  OpenImage(image_info,image,WriteBinaryType);
-  if (image->file == (FILE *) NULL)
+  status=OpenBlob(image_info,image,WriteBinaryType);
+  if (status == False)
     WriterExit(FileOpenWarning,"Unable to open file",image);
   if ((image->file != stdout) && !image->pipe)
     (void) remove(image->filename);
@@ -1174,7 +1200,7 @@ Export unsigned int WriteTIFFImage(const ImageInfo *image_info,Image *image)
       TemporaryFilename(image->filename);
       image->temporary=True;
     }
-  CloseImage(image);
+  CloseBlob(image);
   tiff=TIFFOpen(image->filename,WriteBinaryType);
   if (tiff == (TIFF *) NULL)
     return(False);
@@ -1295,24 +1321,21 @@ Export unsigned int WriteTIFFImage(const ImageInfo *image_info,Image *image)
     }
     TIFFSetField(tiff,TIFFTAG_PHOTOMETRIC,photometric);
     TIFFSetField(tiff,TIFFTAG_COMPRESSION,compress_tag);
-    if (Latin1Compare(image_info->magick,"TIF") == 0)
-      TIFFSetField(tiff,TIFFTAG_FILLORDER,FILLORDER_LSB2MSB);
-    else
-      TIFFSetField(tiff,TIFFTAG_FILLORDER,FILLORDER_MSB2LSB);
+    TIFFSetField(tiff,TIFFTAG_FILLORDER,FILLORDER_MSB2LSB);
     TIFFSetField(tiff,TIFFTAG_ORIENTATION,ORIENTATION_TOPLEFT);
     TIFFSetField(tiff,TIFFTAG_PLANARCONFIG,PLANARCONFIG_CONTIG);
     if (photometric == PHOTOMETRIC_RGB)
       if ((image_info->interlace == PlaneInterlace) ||
           (image_info->interlace == PartitionInterlace))
         TIFFSetField(tiff,TIFFTAG_PLANARCONFIG,PLANARCONFIG_SEPARATE);
+    strip_size=Max(TIFFDefaultStripSize(tiff,-1),1);
     if (compress_tag == COMPRESSION_JPEG)
-      TIFFSetField(tiff,TIFFTAG_ROWSPERSTRIP,TIFFDefaultStripSize(tiff,-1)+
-        (8-(TIFFDefaultStripSize(tiff,-1) % 8)));
+      TIFFSetField(tiff,TIFFTAG_ROWSPERSTRIP,strip_size+(8-(strip_size % 8)));
     else
       if (compress_tag == COMPRESSION_CCITTFAX4)
         TIFFSetField(tiff,TIFFTAG_ROWSPERSTRIP,image->rows);
       else
-        TIFFSetField(tiff,TIFFTAG_ROWSPERSTRIP,TIFFDefaultStripSize(tiff,-1));
+        TIFFSetField(tiff,TIFFTAG_ROWSPERSTRIP,strip_size);
     if ((image->x_resolution != 0) && (image->y_resolution != 0))
       {
         unsigned short
@@ -1403,11 +1426,11 @@ Export unsigned int WriteTIFFImage(const ImageInfo *image_info,Image *image)
                 /*
                   Convert DirectClass packets to contiguous RGB scanlines.
                 */
-                *q++=DownScale(p->red);
-                *q++=DownScale(p->green);
-                *q++=DownScale(p->blue);
+                WriteQuantum(p->red,q);
+                WriteQuantum(p->green,q);
+                WriteQuantum(p->blue,q);
                 if (image->matte)
-                  *q++=DownScale(p->index);
+                  WriteQuantum(p->index,q);
                 x++;
                 if (x == (int) image->columns)
                   {
@@ -1718,7 +1741,7 @@ Export unsigned int WriteTIFFImage(const ImageInfo *image_info,Image *image)
       (void) fclose(file);
       (void) remove(image->filename);
       image->temporary=False;
-      CloseImage(&encode_image);
+      CloseBlob(&encode_image);
     }
   if (Latin1Compare(image_info->magick,"PTIF") == 0)
     DestroyImages(image);
