@@ -94,6 +94,10 @@ Export Image *ReadVIFFImage(const ImageInfo *image_info)
 #define VFF_LOC_IMPLICIT  1
 #define VFF_MAPTYP_NONE  0
 #define VFF_MAPTYP_1_BYTE  1
+#define VFF_MAPTYP_2_BYTE  2
+#define VFF_MAPTYP_4_BYTE  4
+#define VFF_MAPTYP_FLOAT  5
+#define VFF_MAPTYP_DOUBLE  7
 #define VFF_MS_NONE  0
 #define VFF_MS_ONEPERBAND  1
 #define VFF_MS_SHARED  3
@@ -101,6 +105,8 @@ Export Image *ReadVIFFImage(const ImageInfo *image_info)
 #define VFF_TYP_1_BYTE  1
 #define VFF_TYP_2_BYTE  2
 #define VFF_TYP_4_BYTE  4
+#define VFF_TYP_FLOAT  5
+#define VFF_TYP_DOUBLE  9
 
   typedef struct _ViffHeader
   {
@@ -145,6 +151,11 @@ Export Image *ReadVIFFImage(const ImageInfo *image_info)
       color_space_model;
   } ViffHeader;
 
+  double
+    min_value,
+    scale_factor,
+    value;
+
   Image
     *image;
 
@@ -154,12 +165,12 @@ Export Image *ReadVIFFImage(const ImageInfo *image_info)
     x,
     y;
 
-  register Quantum
-    *p;
-
   register RunlengthPacket
     *q;
 
+  register unsigned char
+    *p;
+
   unsigned char
     buffer[7],
     *viff_pixels;
@@ -183,13 +194,13 @@ Export Image *ReadVIFFImage(const ImageInfo *image_info)
   /*
     Open image file.
   */
-  OpenImage(image_info,image,ReadBinaryType);
-  if (image->file == (FILE *) NULL)
+  status=OpenBlob(image_info,image,ReadBinaryType);
+  if (status == False)
     ReaderExit(FileOpenWarning,"Unable to open file",image);
   /*
     Read VIFF header (1024 bytes).
   */
-  status=ReadData((char *) &viff_header.identifier,1,1,image->file);
+  status=ReadBlob(image,1,(char *) &viff_header.identifier);
   do
   {
     /*
@@ -200,66 +211,66 @@ Export Image *ReadVIFFImage(const ImageInfo *image_info)
     /*
       Initialize VIFF image.
     */
-    (void) ReadData((char *) buffer,1,7,image->file);
+    (void) ReadBlob(image,7,(char *) buffer);
     viff_header.file_type=buffer[0];
     viff_header.release=buffer[1];
     viff_header.version=buffer[2];
     viff_header.machine_dependency=buffer[3];
-    (void) ReadData((char *) viff_header.comment,1,512,image->file);
+    (void) ReadBlob(image,512,(char *) viff_header.comment);
     viff_header.comment[511]='\0';
     if (Extent(viff_header.comment) > 4)
       (void) CloneString(&image->comments,viff_header.comment);
     if ((viff_header.machine_dependency == VFF_DEP_DECORDER) ||
         (viff_header.machine_dependency == VFF_DEP_NSORDER))
       {
-        viff_header.rows=LSBFirstReadLong(image->file);
-        viff_header.columns=LSBFirstReadLong(image->file);
-        viff_header.subrows=LSBFirstReadLong(image->file);
-        viff_header.x_offset=(long) LSBFirstReadLong(image->file);
-        viff_header.y_offset=(long) LSBFirstReadLong(image->file);
-        viff_header.x_bits_per_pixel=(float) LSBFirstReadLong(image->file);
-        viff_header.y_bits_per_pixel=(float) LSBFirstReadLong(image->file);
-        viff_header.location_type=LSBFirstReadLong(image->file);
-        viff_header.location_dimension=LSBFirstReadLong(image->file);
-        viff_header.number_of_images=LSBFirstReadLong(image->file);
-        viff_header.number_data_bands=LSBFirstReadLong(image->file);
-        viff_header.data_storage_type=LSBFirstReadLong(image->file);
-        viff_header.data_encode_scheme=LSBFirstReadLong(image->file);
-        viff_header.map_scheme=LSBFirstReadLong(image->file);
-        viff_header.map_storage_type=LSBFirstReadLong(image->file);
-        viff_header.map_rows=LSBFirstReadLong(image->file);
-        viff_header.map_columns=LSBFirstReadLong(image->file);
-        viff_header.map_subrows=LSBFirstReadLong(image->file);
-        viff_header.map_enable=LSBFirstReadLong(image->file);
-        viff_header.maps_per_cycle=LSBFirstReadLong(image->file);
-        viff_header.color_space_model=LSBFirstReadLong(image->file);
+        viff_header.rows=LSBFirstReadLong(image);
+        viff_header.columns=LSBFirstReadLong(image);
+        viff_header.subrows=LSBFirstReadLong(image);
+        viff_header.x_offset=(long) LSBFirstReadLong(image);
+        viff_header.y_offset=(long) LSBFirstReadLong(image);
+        viff_header.x_bits_per_pixel=(float) LSBFirstReadLong(image);
+        viff_header.y_bits_per_pixel=(float) LSBFirstReadLong(image);
+        viff_header.location_type=LSBFirstReadLong(image);
+        viff_header.location_dimension=LSBFirstReadLong(image);
+        viff_header.number_of_images=LSBFirstReadLong(image);
+        viff_header.number_data_bands=LSBFirstReadLong(image);
+        viff_header.data_storage_type=LSBFirstReadLong(image);
+        viff_header.data_encode_scheme=LSBFirstReadLong(image);
+        viff_header.map_scheme=LSBFirstReadLong(image);
+        viff_header.map_storage_type=LSBFirstReadLong(image);
+        viff_header.map_rows=LSBFirstReadLong(image);
+        viff_header.map_columns=LSBFirstReadLong(image);
+        viff_header.map_subrows=LSBFirstReadLong(image);
+        viff_header.map_enable=LSBFirstReadLong(image);
+        viff_header.maps_per_cycle=LSBFirstReadLong(image);
+        viff_header.color_space_model=LSBFirstReadLong(image);
       }
     else
       {
-        viff_header.rows=MSBFirstReadLong(image->file);
-        viff_header.columns=MSBFirstReadLong(image->file);
-        viff_header.subrows=MSBFirstReadLong(image->file);
-        viff_header.x_offset=(long) MSBFirstReadLong(image->file);
-        viff_header.y_offset=(long) MSBFirstReadLong(image->file);
-        viff_header.x_bits_per_pixel=(float) MSBFirstReadLong(image->file);
-        viff_header.y_bits_per_pixel=(float) MSBFirstReadLong(image->file);
-        viff_header.location_type=MSBFirstReadLong(image->file);
-        viff_header.location_dimension=MSBFirstReadLong(image->file);
-        viff_header.number_of_images=MSBFirstReadLong(image->file);
-        viff_header.number_data_bands=MSBFirstReadLong(image->file);
-        viff_header.data_storage_type=MSBFirstReadLong(image->file);
-        viff_header.data_encode_scheme=MSBFirstReadLong(image->file);
-        viff_header.map_scheme=MSBFirstReadLong(image->file);
-        viff_header.map_storage_type=MSBFirstReadLong(image->file);
-        viff_header.map_rows=MSBFirstReadLong(image->file);
-        viff_header.map_columns=MSBFirstReadLong(image->file);
-        viff_header.map_subrows=MSBFirstReadLong(image->file);
-        viff_header.map_enable=MSBFirstReadLong(image->file);
-        viff_header.maps_per_cycle=MSBFirstReadLong(image->file);
-        viff_header.color_space_model=MSBFirstReadLong(image->file);
+        viff_header.rows=MSBFirstReadLong(image);
+        viff_header.columns=MSBFirstReadLong(image);
+        viff_header.subrows=MSBFirstReadLong(image);
+        viff_header.x_offset=(long) MSBFirstReadLong(image);
+        viff_header.y_offset=(long) MSBFirstReadLong(image);
+        viff_header.x_bits_per_pixel=(float) MSBFirstReadLong(image);
+        viff_header.y_bits_per_pixel=(float) MSBFirstReadLong(image);
+        viff_header.location_type=MSBFirstReadLong(image);
+        viff_header.location_dimension=MSBFirstReadLong(image);
+        viff_header.number_of_images=MSBFirstReadLong(image);
+        viff_header.number_data_bands=MSBFirstReadLong(image);
+        viff_header.data_storage_type=MSBFirstReadLong(image);
+        viff_header.data_encode_scheme=MSBFirstReadLong(image);
+        viff_header.map_scheme=MSBFirstReadLong(image);
+        viff_header.map_storage_type=MSBFirstReadLong(image);
+        viff_header.map_rows=MSBFirstReadLong(image);
+        viff_header.map_columns=MSBFirstReadLong(image);
+        viff_header.map_subrows=MSBFirstReadLong(image);
+        viff_header.map_enable=MSBFirstReadLong(image);
+        viff_header.maps_per_cycle=MSBFirstReadLong(image);
+        viff_header.color_space_model=MSBFirstReadLong(image);
       }
     for (i=0; i < 420; i++)
-      (void) fgetc(image->file);
+      (void) ReadByte(image);
     image->columns=(unsigned int) viff_header.rows;
     image->rows=(unsigned int) viff_header.columns;
     /*
@@ -271,21 +282,25 @@ Export Image *ReadVIFFImage(const ImageInfo *image_info)
     if ((viff_header.data_storage_type != VFF_TYP_BIT) &&
         (viff_header.data_storage_type != VFF_TYP_1_BYTE) &&
         (viff_header.data_storage_type != VFF_TYP_2_BYTE) &&
-        (viff_header.data_storage_type != VFF_TYP_4_BYTE))
+        (viff_header.data_storage_type != VFF_TYP_4_BYTE) &&
+        (viff_header.data_storage_type != VFF_TYP_FLOAT) &&
+        (viff_header.data_storage_type != VFF_TYP_DOUBLE))
       ReaderExit(CorruptImageWarning,
         "Data storage type is not supported",image);
     if (viff_header.data_encode_scheme != VFF_DES_RAW)
       ReaderExit(CorruptImageWarning,
         "Data encoding scheme is not supported",image);
     if ((viff_header.map_storage_type != VFF_MAPTYP_NONE) &&
-        (viff_header.map_storage_type != VFF_MAPTYP_1_BYTE))
-      ReaderExit(CorruptImageWarning,
-        "Map storage type is not supported",image);
+        (viff_header.map_storage_type != VFF_MAPTYP_1_BYTE) &&
+        (viff_header.map_storage_type != VFF_MAPTYP_2_BYTE) &&
+        (viff_header.map_storage_type != VFF_MAPTYP_4_BYTE) &&
+        (viff_header.map_storage_type != VFF_MAPTYP_FLOAT) &&
+        (viff_header.map_storage_type != VFF_MAPTYP_DOUBLE))
+      ReaderExit(CorruptImageWarning,"Map storage type is not supported",image);
     if ((viff_header.color_space_model != VFF_CM_NONE) &&
         (viff_header.color_space_model != VFF_CM_ntscRGB) &&
         (viff_header.color_space_model != VFF_CM_genericRGB))
-      ReaderExit(CorruptImageWarning,
-        "Colorspace model is not supported",image);
+      ReaderExit(CorruptImageWarning,"Colorspace model is not supported",image);
     if (viff_header.location_type != VFF_LOC_IMPLICIT)
       {
         MagickWarning(CorruptImageWarning,
@@ -294,8 +309,9 @@ Export Image *ReadVIFFImage(const ImageInfo *image_info)
         return((Image *) NULL);
       }
     if (viff_header.number_of_images != 1)
-      ReaderExit(CorruptImageWarning,
-        "Number of images is not supported",image);
+      ReaderExit(CorruptImageWarning,"Number of images is not supported",image);
+    if (viff_header.map_rows == 0)
+      viff_header.map_scheme=VFF_MS_NONE;
     switch (viff_header.map_scheme)
     {
       case VFF_MS_NONE:
@@ -330,50 +346,91 @@ Export Image *ReadVIFFImage(const ImageInfo *image_info)
           *viff_colormap;
 
         /*
-          Read VIFF raster colormap.
+          Allocate VIFF colormap.
         */
+        switch (viff_header.map_storage_type)
+        {
+          case VFF_MAPTYP_1_BYTE: bytes_per_pixel=1; break;
+          case VFF_MAPTYP_2_BYTE: bytes_per_pixel=2; break;
+          case VFF_MAPTYP_4_BYTE: bytes_per_pixel=4; break;
+          case VFF_MAPTYP_FLOAT: bytes_per_pixel=4; break;
+          case VFF_MAPTYP_DOUBLE: bytes_per_pixel=8; break;
+          default: bytes_per_pixel=1; break;
+        }
         image->colors=(unsigned int) viff_header.map_columns;
         image->colormap=(ColorPacket *)
           AllocateMemory(image->colors*sizeof(ColorPacket));
-        viff_colormap=(unsigned char *)
-          AllocateMemory(image->colors*sizeof(unsigned char));
+        viff_colormap=(unsigned char *) AllocateMemory(bytes_per_pixel*
+          image->colors*viff_header.map_rows*sizeof(unsigned char));
         if ((image->colormap == (ColorPacket *) NULL) ||
             (viff_colormap == (unsigned char *) NULL))
           ReaderExit(ResourceLimitWarning,"Memory allocation failed",image);
-        (void) ReadData((char *) viff_colormap,1,image->colors,image->file);
-        for (i=0; i < (int) image->colors; i++)
+        /*
+          Read VIFF raster colormap.
+        */
+        (void) ReadBlob(image,bytes_per_pixel*
+          image->colors*viff_header.map_rows,(char *) viff_colormap);
+        if ((viff_header.machine_dependency == VFF_DEP_DECORDER) ||
+            (viff_header.machine_dependency == VFF_DEP_NSORDER))
+          switch (viff_header.map_storage_type)
+          {
+            case VFF_MAPTYP_2_BYTE:
+            {
+              MSBFirstOrderShort((char *) viff_colormap,(unsigned int)
+                (bytes_per_pixel*image->colors*viff_header.map_rows));
+              break;
+            }
+            case VFF_MAPTYP_4_BYTE:
+            case VFF_MAPTYP_FLOAT:
+            {
+              MSBFirstOrderLong((char *) viff_colormap,(unsigned int)
+                (bytes_per_pixel*image->colors*viff_header.map_rows));
+              break;
+            }
+            default: break;
+          }
+        for (i=0; i < (int) (viff_header.map_rows*image->colors); i++)
         {
-          image->colormap[i].red=UpScale(viff_colormap[i]);
-          image->colormap[i].green=UpScale(viff_colormap[i]);
-          image->colormap[i].blue=UpScale(viff_colormap[i]);
+          switch (viff_header.map_storage_type)
+          {
+            case VFF_MAPTYP_2_BYTE: value=((short *) viff_colormap)[i]; break;
+            case VFF_MAPTYP_4_BYTE: value=((int *) viff_colormap)[i]; break;
+            case VFF_MAPTYP_FLOAT: value=((float *) viff_colormap)[i]; break;
+            case VFF_MAPTYP_DOUBLE: value=((double *) viff_colormap)[i]; break;
+            default: value=viff_colormap[i]; break;
+          }
+          if (i < (int) image->colors)
+            {
+              image->colormap[i].red=UpScale((unsigned int) value);
+              image->colormap[i].green=UpScale((unsigned int) value);
+              image->colormap[i].blue=UpScale((unsigned int) value);
+            }
+          else
+            if (i < (int) (2*image->colors))
+              image->colormap[i % image->colors].green=
+                UpScale((unsigned int) value);
+            else
+              if (i < (int) (3*image->colors))
+                image->colormap[i % image->colors].blue=
+                  UpScale((unsigned int) value);
         }
-        if (viff_header.map_rows > 1)
-          {
-            (void) ReadData((char *) viff_colormap,1,image->colors,image->file);
-            for (i=0; i < (int) image->colors; i++)
-              image->colormap[i].green=UpScale(viff_colormap[i]);
-          }
-        if (viff_header.map_rows > 2)
-          {
-            (void) ReadData((char *) viff_colormap,1,image->colors,image->file);
-            for (i=0; i < (int) image->colors; i++)
-              image->colormap[i].blue=UpScale(viff_colormap[i]);
-          }
         FreeMemory((char *) viff_colormap);
         break;
       }
       default:
-        ReaderExit(CorruptImageWarning,"Colormap type is not supported",
-          image);
+        ReaderExit(CorruptImageWarning,"Colormap type is not supported",image);
     }
     /*
       Allocate VIFF pixels.
     */
-    bytes_per_pixel=1;
-    if (viff_header.data_storage_type == VFF_TYP_2_BYTE)
-      bytes_per_pixel=2;
-    if (viff_header.data_storage_type == VFF_TYP_4_BYTE)
-      bytes_per_pixel=4;
+    switch (viff_header.data_storage_type)
+    {
+      case VFF_TYP_2_BYTE: bytes_per_pixel=2; break;
+      case VFF_TYP_4_BYTE: bytes_per_pixel=4; break;
+      case VFF_TYP_FLOAT: bytes_per_pixel=4; break;
+      case VFF_TYP_DOUBLE: bytes_per_pixel=8; break;
+      default: bytes_per_pixel=1; break;
+    }
     if (viff_header.data_storage_type == VFF_TYP_BIT)
       max_packets=((viff_header.columns+7) >> 3)*viff_header.rows;
     else
@@ -383,156 +440,98 @@ Export Image *ReadVIFFImage(const ImageInfo *image_info)
       AllocateMemory(bytes_per_pixel*max_packets*sizeof(Quantum));
     if (viff_pixels == (unsigned char *) NULL)
       ReaderExit(ResourceLimitWarning,"Memory allocation failed",image);
-    (void) ReadData((char *) viff_pixels,bytes_per_pixel,(unsigned int)
-      max_packets,image->file);
-    switch (viff_header.data_storage_type)
-    {
-      int
-        max_value,
-        min_value,
-        value;
-
-      register Quantum
-        *q;
-
-      unsigned long
-        scale_factor;
-
-      case VFF_TYP_1_BYTE:
+    (void) ReadBlob(image,bytes_per_pixel*max_packets,(char *) viff_pixels);
+    if ((viff_header.machine_dependency == VFF_DEP_DECORDER) ||
+        (viff_header.machine_dependency == VFF_DEP_NSORDER))
+      switch (viff_header.data_storage_type)
       {
-        register unsigned char
-          *p;
-
-        if (QuantumDepth == 8)
+        case VFF_TYP_2_BYTE:
+        {
+          MSBFirstOrderShort((char *) viff_pixels,(unsigned int)
+            (bytes_per_pixel*max_packets));
           break;
-        /*
-          Scale integer pixels to [0..MaxRGB].
-        */
-        p=viff_pixels;
-        q=(Quantum *) viff_pixels;
-        p+=max_packets-1;
-        q+=max_packets-1;
-        for (i=0; i < (int) max_packets; i++)
-        {
-          value=UpScale(*p);
-          *q=(Quantum) value;
-          p--;
-          q--;
         }
-        break;
+        case VFF_TYP_4_BYTE:
+        case VFF_TYP_FLOAT:
+        {
+          MSBFirstOrderLong((char *) viff_pixels,(unsigned int)
+            (bytes_per_pixel*max_packets));
+          break;
+        }
+        default: break;
       }
-      case VFF_TYP_2_BYTE:
+    min_value=0.0;
+    scale_factor=1.0;
+    if (viff_header.map_scheme == VFF_MS_NONE)
       {
-        register short int
-          *p;
+        double
+          max_value;
 
-        /*
-          Ensure the header byte-order is most-significant byte first.
-        */
-        if ((viff_header.machine_dependency == VFF_DEP_DECORDER) ||
-            (viff_header.machine_dependency == VFF_DEP_NSORDER))
-          MSBFirstOrderShort((char *) &viff_header,
-            (unsigned int) (bytes_per_pixel*max_packets));
         /*
           Determine scale factor.
         */
-        p=(short int *) viff_pixels;
-        max_value=(*p);
-        min_value=(*p);
+        switch (viff_header.data_storage_type)
+        {
+          case VFF_TYP_2_BYTE: value=((short *) viff_pixels)[0]; break;
+          case VFF_TYP_4_BYTE: value=((int *) viff_pixels)[0]; break;
+          case VFF_TYP_FLOAT: value=((float *) viff_pixels)[0]; break;
+          case VFF_TYP_DOUBLE: value=((double *) viff_pixels)[0]; break;
+          default: value=viff_pixels[0]; break;
+        }
+        max_value=value;
+        min_value=value;
         for (i=0; i < (int) max_packets; i++)
         {
-          if (*p > max_value)
-            max_value=(*p);
+          switch (viff_header.data_storage_type)
+          {
+            case VFF_TYP_2_BYTE: value=((short *) viff_pixels)[i]; break;
+            case VFF_TYP_4_BYTE: value=((int *) viff_pixels)[i]; break;
+            case VFF_TYP_FLOAT: value=((float *) viff_pixels)[i]; break;
+            case VFF_TYP_DOUBLE: value=((double *) viff_pixels)[i]; break;
+            default: value=viff_pixels[i]; break;
+          }
+          if (value > max_value)
+            max_value=value;
           else
-            if (*p < min_value)
-              min_value=(*p);
-          p++;
+            if (value < min_value)
+              min_value=value;
         }
         if ((min_value == 0) && (max_value == 0))
           scale_factor=0;
         else
           if (min_value == max_value)
             {
-              scale_factor=UpShift(MaxRGB)/min_value;
+              scale_factor=(double) MaxRGB/min_value;
               min_value=0;
             }
           else
-            scale_factor=UpShift(MaxRGB)/(max_value-min_value);
-        /*
-          Scale integer pixels to [0..MaxRGB].
-        */
-        p=(short int *) viff_pixels;
-        q=(Quantum *) viff_pixels;
-        for (i=0; i < (int) max_packets; i++)
-        {
-          value=DownShift((*p-min_value)*scale_factor);
-          if (value > MaxRGB)
-            value=MaxRGB;
-          else
-            if (value < 0)
-              value=0;
-          *q=(Quantum) value;
-          p++;
-          q++;
-        }
-        break;
+            scale_factor=(double) MaxRGB/(max_value-min_value);
       }
-      case VFF_TYP_4_BYTE:
+    /*
+      Convert pixels to Quantum size.
+    */
+    p=(unsigned char *) viff_pixels;
+    for (i=0; i < (int) max_packets; i++)
+    {
+      switch (viff_header.data_storage_type)
       {
-        register int
-          *p;
-
-        /*
-          Ensure the header byte-order is most-significant byte first.
-        */
-        if ((viff_header.machine_dependency == VFF_DEP_DECORDER) ||
-            (viff_header.machine_dependency == VFF_DEP_NSORDER))
-          MSBFirstOrderLong((char *) &viff_header,
-            (unsigned int) (bytes_per_pixel*max_packets));
-        /*
-          Determine scale factor.
-        */
-        p=(int *) viff_pixels;
-        max_value=(*p);
-        min_value=(*p);
-        for (i=0; i < (int) max_packets; i++)
+        case VFF_TYP_2_BYTE: value=((short *) viff_pixels)[i]; break;
+        case VFF_TYP_4_BYTE: value=((int *) viff_pixels)[i]; break;
+        case VFF_TYP_FLOAT: value=((float *) viff_pixels)[i]; break;
+        case VFF_TYP_DOUBLE: value=((double *) viff_pixels)[i]; break;
+        default: value=viff_pixels[i]; break;
+      }
+      if (viff_header.map_scheme == VFF_MS_NONE)
         {
-          if (*p > max_value)
-            max_value=(*p);
-          else
-            if (*p < min_value)
-              min_value=(*p);
-          p++;
-        }
-        if ((min_value == 0) && (max_value == 0))
-          scale_factor=0;
-        else
-          if (min_value == max_value)
-            {
-              scale_factor=UpShift(MaxRGB)/min_value;
-              min_value=0;
-            }
-          else
-            scale_factor=UpShift(MaxRGB)/(max_value-min_value);
-        /*
-          Scale integer pixels to [0..MaxRGB].
-        */
-        p=(int *) viff_pixels;
-        q=(Quantum *) viff_pixels;
-        for (i=0; i < (int) max_packets; i++)
-        {
-          value=DownShift((*p-min_value)*scale_factor);
+          value=(value-min_value)*scale_factor;
           if (value > MaxRGB)
             value=MaxRGB;
           else
             if (value < 0)
               value=0;
-          *q=(unsigned char) value;
-          p++;
-          q++;
         }
-        break;
-      }
+      *p=(Quantum) value;
+      p++;
     }
     /*
       Initialize image structure.
@@ -544,7 +543,7 @@ Export Image *ReadVIFFImage(const ImageInfo *image_info)
     image->rows=(unsigned int) viff_header.columns;
     if (image_info->ping)
       {
-        CloseImage(image);
+        CloseBlob(image);
         return(image);
       }
     image->packets=image->columns*image->rows;
@@ -556,7 +555,7 @@ Export Image *ReadVIFFImage(const ImageInfo *image_info)
     /*
       Convert VIFF raster image to runlength-encoded packets.
     */
-    p=(Quantum *) viff_pixels;
+    p=(unsigned char *) viff_pixels;
     q=image->pixels;
     if (viff_header.data_storage_type == VFF_TYP_BIT)
       {
@@ -566,8 +565,10 @@ Export Image *ReadVIFFImage(const ImageInfo *image_info)
         /*
           Convert bitmap scanline to runlength-encoded color packets.
         */
-        polarity=(viff_header.machine_dependency == VFF_DEP_DECORDER) ||
-          (viff_header.machine_dependency == VFF_DEP_NSORDER);
+        polarity=0;
+        if (image->colors >= 2)
+          polarity=Intensity(image->colormap[0]) <
+            Intensity(image->colormap[1]);
         for (y=0; y < (int) image->rows; y++)
         {
           /*
@@ -659,7 +660,7 @@ Export Image *ReadVIFFImage(const ImageInfo *image_info)
     if (image_info->subrange != 0)
       if (image->scene >= (image_info->subimage+image_info->subrange-1))
         break;
-    status=ReadData((char *) &viff_header.identifier,1,1,image->file);
+    status=ReadBlob(image,1,(char *) &viff_header.identifier);
     if ((status == True) && (viff_header.identifier == 0xab))
       {
         /*
@@ -672,13 +673,13 @@ Export Image *ReadVIFFImage(const ImageInfo *image_info)
             return((Image *) NULL);
           }
         image=image->next;
-        ProgressMonitor(LoadImagesText,(unsigned int) ftell(image->file),
+        ProgressMonitor(LoadImagesText,(unsigned int) TellBlob(image),
           (unsigned int) image->filesize);
       }
   } while ((status == True) && (viff_header.identifier == 0xab));
   while (image->previous != (Image *) NULL)
     image=image->previous;
-  CloseImage(image);
+  CloseBlob(image);
   return(image);
 }
 
@@ -781,7 +782,8 @@ Export unsigned int WriteVIFFImage(const ImageInfo *image_info,Image *image)
     *viff_pixels;
 
   unsigned int
-    scene;
+    scene,
+    status;
 
   unsigned long
     packets;
@@ -792,8 +794,8 @@ Export unsigned int WriteVIFFImage(const ImageInfo *image_info,Image *image)
   /*
     Open output image file.
   */
-  OpenImage(image_info,image,WriteBinaryType);
-  if (image->file == (FILE *) NULL)
+  status=OpenBlob(image_info,image,WriteBinaryType);
+  if (status == False)
     WriterExit(FileOpenWarning,"Unable to open file",image);
   scene=0;
   do
@@ -879,33 +881,33 @@ Export unsigned int WriteVIFFImage(const ImageInfo *image_info,Image *image)
     buffer[5]=viff_header.reserve[0];
     buffer[6]=viff_header.reserve[1];
     buffer[7]=viff_header.reserve[2];
-    (void) fwrite((char *) buffer,1,8,image->file);
-    (void) fwrite((char *) viff_header.comment,1,512,image->file);
-    MSBFirstWriteLong(viff_header.rows,image->file);
-    MSBFirstWriteLong(viff_header.columns,image->file);
-    MSBFirstWriteLong(viff_header.subrows,image->file);
-    MSBFirstWriteLong((unsigned long) viff_header.x_offset,image->file);
-    MSBFirstWriteLong((unsigned long) viff_header.y_offset,image->file);
+    (void) WriteBlob(image,8,(char *) buffer);
+    (void) WriteBlob(image,512,(char *) viff_header.comment);
+    MSBFirstWriteLong(image,viff_header.rows);
+    MSBFirstWriteLong(image,viff_header.columns);
+    MSBFirstWriteLong(image,viff_header.subrows);
+    MSBFirstWriteLong(image,(unsigned long) viff_header.x_offset);
+    MSBFirstWriteLong(image,(unsigned long) viff_header.y_offset);
     viff_header.x_bits_per_pixel=(63 << 24) | (128 << 16);
-    MSBFirstWriteLong((unsigned long) viff_header.x_bits_per_pixel,image->file);
+    MSBFirstWriteLong(image,(unsigned long) viff_header.x_bits_per_pixel);
     viff_header.y_bits_per_pixel=(63 << 24) | (128 << 16);
-    MSBFirstWriteLong((unsigned long) viff_header.y_bits_per_pixel,image->file);
-    MSBFirstWriteLong(viff_header.location_type,image->file);
-    MSBFirstWriteLong(viff_header.location_dimension,image->file);
-    MSBFirstWriteLong(viff_header.number_of_images,image->file);
-    MSBFirstWriteLong(viff_header.number_data_bands,image->file);
-    MSBFirstWriteLong(viff_header.data_storage_type,image->file);
-    MSBFirstWriteLong(viff_header.data_encode_scheme,image->file);
-    MSBFirstWriteLong(viff_header.map_scheme,image->file);
-    MSBFirstWriteLong(viff_header.map_storage_type,image->file);
-    MSBFirstWriteLong(viff_header.map_rows,image->file);
-    MSBFirstWriteLong(viff_header.map_columns,image->file);
-    MSBFirstWriteLong(viff_header.map_subrows,image->file);
-    MSBFirstWriteLong(viff_header.map_enable,image->file);
-    MSBFirstWriteLong(viff_header.maps_per_cycle,image->file);
-    MSBFirstWriteLong(viff_header.color_space_model,image->file);
+    MSBFirstWriteLong(image,(unsigned long) viff_header.y_bits_per_pixel);
+    MSBFirstWriteLong(image,viff_header.location_type);
+    MSBFirstWriteLong(image,viff_header.location_dimension);
+    MSBFirstWriteLong(image,viff_header.number_of_images);
+    MSBFirstWriteLong(image,viff_header.number_data_bands);
+    MSBFirstWriteLong(image,viff_header.data_storage_type);
+    MSBFirstWriteLong(image,viff_header.data_encode_scheme);
+    MSBFirstWriteLong(image,viff_header.map_scheme);
+    MSBFirstWriteLong(image,viff_header.map_storage_type);
+    MSBFirstWriteLong(image,viff_header.map_rows);
+    MSBFirstWriteLong(image,viff_header.map_columns);
+    MSBFirstWriteLong(image,viff_header.map_subrows);
+    MSBFirstWriteLong(image,viff_header.map_enable);
+    MSBFirstWriteLong(image,viff_header.maps_per_cycle);
+    MSBFirstWriteLong(image,viff_header.color_space_model);
     for (i=0; i < 420; i++)
-      (void) fputc('\0',image->file);
+      (void) WriteByte(image,'\0');
     /*
       Convert MIFF to VIFF raster pixels.
     */
@@ -961,8 +963,7 @@ Export unsigned int WriteVIFFImage(const ImageInfo *image_info,Image *image)
             *q++=DownScale(image->colormap[i].green);
           for (i=0; i < (int) image->colors; i++)
             *q++=DownScale(image->colormap[i].blue);
-          (void) fwrite((char *) viff_colormap,1,(int) image->colors*3,
-            image->file);
+          (void) WriteBlob(image,3*image->colors,(char *) viff_colormap);
           FreeMemory((char *) viff_colormap);
           /*
             Convert PseudoClass packet to VIFF colormapped pixels.
@@ -1050,7 +1051,7 @@ Export unsigned int WriteVIFFImage(const ImageInfo *image_info,Image *image)
                   ProgressMonitor(SaveImageText,i,image->packets);
             }
           }
-    (void) fwrite((char *) viff_pixels,1,(int) packets,image->file);
+    (void) WriteBlob(image,packets,(char *) viff_pixels);
     FreeMemory((char *) viff_pixels);
     if (image->next == (Image *) NULL)
       break;
@@ -1061,6 +1062,6 @@ Export unsigned int WriteVIFFImage(const ImageInfo *image_info,Image *image)
   if (image_info->adjoin)
     while (image->previous != (Image *) NULL)
       image=image->previous;
-  CloseImage(image);
+  CloseBlob(image);
   return(True);
 }
