@@ -399,6 +399,7 @@ Export Image *ReadXPMImage(const ImageInfo *image_info)
     *r;
 
   unsigned int
+    status,
     width;
 
   /*
@@ -410,8 +411,8 @@ Export Image *ReadXPMImage(const ImageInfo *image_info)
   /*
     Open image file.
   */
-  OpenImage(image_info,image,"r");
-  if (image->file == (FILE *) NULL)
+  status=OpenBlob(image_info,image,"r");
+  if (status == False)
     ReaderExit(FileOpenWarning,"Unable to open file",image);
   /*
     Read XPM file.
@@ -420,7 +421,7 @@ Export Image *ReadXPMImage(const ImageInfo *image_info)
   xpm_buffer=(char *) AllocateMemory(length*sizeof(char));
   p=xpm_buffer;
   if (xpm_buffer != (char *) NULL)
-    while (fgets(p,MaxTextExtent,image->file) != (char *) NULL)
+    while (GetStringBlob(image,p) != (char *) NULL)
     {
       if (*p == '#')
         if ((p == xpm_buffer) || (*(p-1) == '\n'))
@@ -561,7 +562,7 @@ Export Image *ReadXPMImage(const ImageInfo *image_info)
     }
   if (image_info->ping)
     {
-      CloseImage(image);
+      CloseBlob(image);
       return(image);
     }
   /*
@@ -622,7 +623,7 @@ Export Image *ReadXPMImage(const ImageInfo *image_info)
     FreeMemory((char *) textlist[i]);
   FreeMemory((char *) textlist);
   CondenseImage(image);
-  CloseImage(image);
+  CloseBlob(image);
   return(image);
 }
 
@@ -664,6 +665,7 @@ Export unsigned int WriteXPMImage(const ImageInfo *image_info,Image *image)
                          "lzxcvbnmMNBVCZASDFGHJKLPIUYTREWQ!~^/()_`'][{}|";
 
   char
+    buffer[MaxTextExtent],
     name[MaxTextExtent],
     symbol[MaxTextExtent];
 
@@ -696,13 +698,14 @@ Export unsigned int WriteXPMImage(const ImageInfo *image_info,Image *image)
   unsigned int
     characters_per_pixel,
     colors,
+    status,
     transparent;
 
   /*
     Open output image file.
   */
-  OpenImage(image_info,image,WriteBinaryType);
-  if (image->file == (FILE *) NULL)
+  status=OpenBlob(image_info,image,WriteBinaryType);
+  if (status == False)
     WriterExit(FileOpenWarning,"Unable to open file",image);
   TransformRGBImage(image,RGBColorspace);
   transparent=False;
@@ -771,11 +774,15 @@ Export unsigned int WriteXPMImage(const ImageInfo *image_info,Image *image)
   /*
     XPM header.
   */
-  (void) fprintf(image->file,"/* XPM */\n");
-  (void) fprintf(image->file,"static char *magick[] = {\n");
-  (void) fprintf(image->file,"/* columns rows colors chars-per-pixel */\n");
-  (void) fprintf(image->file,"\"%u %u %u %d\",\n",image->columns,
+  (void) strcpy(buffer,"/* XPM */\n");
+  (void) WriteBlob(image,strlen(buffer),buffer);
+  (void) strcpy(buffer,"static char *magick[] = {\n");
+  (void) WriteBlob(image,strlen(buffer),buffer);
+  (void) strcpy(buffer,"/* columns rows colors chars-per-pixel */\n");
+  (void) WriteBlob(image,strlen(buffer),buffer);
+  (void) sprintf(buffer,"\"%u %u %u %d\",\n",image->columns,
     image->rows,colors,characters_per_pixel);
+  (void) WriteBlob(image,strlen(buffer),buffer);
   for (i=0; i < (int) colors; i++)
   {
     ColorPacket
@@ -818,17 +825,20 @@ Export unsigned int WriteXPMImage(const ImageInfo *image_info,Image *image)
       symbol[j]=Cixel[k];
     }
     symbol[j]='\0';
-    (void) fprintf(image->file,"\"%.1024s c %.1024s\",\n",symbol,name);
+    (void) sprintf(buffer,"\"%.1024s c %.1024s\",\n",symbol,name);
+    (void) WriteBlob(image,strlen(buffer),buffer);
   }
   /*
     Define XPM pixels.
   */
-  (void) fprintf(image->file,"/* pixels */\n");
+  (void) strcpy(buffer,"/* pixels */\n");
+  (void) WriteBlob(image,strlen(buffer),buffer);
   p=image->pixels;
   runlength=p->length+1;
   for (y=0; y < (int) image->rows; y++)
   {
-    (void) fprintf(image->file,"\"");
+    (void) strcpy(buffer,"\"");
+    (void) WriteBlob(image,strlen(buffer),buffer);
     for (x=0; x < (int) image->columns; x++)
     {
       if (runlength != 0)
@@ -846,14 +856,17 @@ Export unsigned int WriteXPMImage(const ImageInfo *image_info,Image *image)
         symbol[j]=Cixel[k];
       }
       symbol[j]='\0';
-      (void) fprintf(image->file,"%.1024s",symbol);
+      (void) sprintf(buffer,"%.1024s",symbol);
+      (void) WriteBlob(image,strlen(buffer),buffer);
     }
-    (void) fprintf(image->file,"\"%.1024s\n",
+    (void) sprintf(buffer,"\"%.1024s\n",
       (y == (int) (image->rows-1) ? "" : ","));
+    (void) WriteBlob(image,strlen(buffer),buffer);
     if (QuantumTick(y,image->rows))
       ProgressMonitor(SaveImageText,y,image->rows);
   }
-  (void) fprintf(image->file,"};\n");
-  CloseImage(image);
+  (void) strcpy(buffer,"};\n");
+  (void) WriteBlob(image,strlen(buffer),buffer);
+  CloseBlob(image);
   return(True);
 }
