@@ -132,13 +132,13 @@ Export Image *ReadXWDImage(const ImageInfo *image_info)
   /*
     Open image file.
   */
-  OpenImage(image_info,image,ReadBinaryType);
-  if (image->file == (FILE *) NULL)
+  status=OpenBlob(image_info,image,ReadBinaryType);
+  if (status == False)
     ReaderExit(FileOpenWarning,"Unable to open file",image);
   /*
      Read in header information.
   */
-  status=ReadData((char *) &header,sz_XWDheader,1,image->file);
+  status=ReadBlob(image,sz_XWDheader,(char *) &header);
   if (status == False)
     ReaderExit(CorruptImageWarning,"Unable to read dump file header",image);
   image->columns=header.pixmap_width;
@@ -160,7 +160,7 @@ Export Image *ReadXWDImage(const ImageInfo *image_info)
   image->comments=(char *) AllocateMemory((max_packets+1)*sizeof(char));
   if (image->comments == (char *) NULL)
     ReaderExit(ResourceLimitWarning,"Memory allocation failed",image);
-  status=ReadData((char *) image->comments,1,max_packets,image->file);
+  status=ReadBlob(image,max_packets,(char *) image->comments);
   image->comments[max_packets]='\0';
   if (status == False)
     ReaderExit(CorruptImageWarning,
@@ -204,7 +204,7 @@ Export Image *ReadXWDImage(const ImageInfo *image_info)
         ReaderExit(ResourceLimitWarning,"Memory allocation failed",image);
       for (i=0; i < (int) header.ncolors; i++)
       {
-        status=ReadData((char *) &color,sz_XWDColor,1,image->file);
+        status=ReadBlob(image,sz_XWDColor,(char *) &color);
         if (status == False)
           ReaderExit(CorruptImageWarning,
             "Unable to read color map from dump file",image);
@@ -235,7 +235,7 @@ Export Image *ReadXWDImage(const ImageInfo *image_info)
   ximage->data=(char *) AllocateMemory(max_packets*sizeof(unsigned char));
   if (ximage->data == (char *) NULL)
     ReaderExit(ResourceLimitWarning,"Memory allocation failed",image);
-  status=ReadData(ximage->data,1,max_packets,image->file);
+  status=ReadBlob(image,max_packets,ximage->data);
   if (status == False)
     ReaderExit(CorruptImageWarning,"Unable to read dump pixmap",image);
   /*
@@ -253,7 +253,7 @@ Export Image *ReadXWDImage(const ImageInfo *image_info)
     {
       if (header.ncolors != 0)
         FreeMemory((char *) colors);
-      CloseImage(image);
+      CloseBlob(image);
       return(image);
     }
   packets=0;
@@ -452,7 +452,7 @@ Export Image *ReadXWDImage(const ImageInfo *image_info)
     FreeMemory((char *) colors);
   FreeMemory(ximage->data);
   FreeMemory(ximage);
-  CloseImage(image);
+  CloseBlob(image);
   return(image);
 }
 #else
@@ -517,22 +517,20 @@ Export unsigned int WriteXWDImage(const ImageInfo *image_info,Image *image)
   unsigned int
     bits_per_pixel,
     bytes_per_line,
-    scanline_pad;
+    scanline_pad,
+    status;
 
   unsigned long
     lsb_first;
 
-  unsigned short
-    value;
-
   XWDFileHeader
     xwd_header;
 
   /*
     Open output image file.
   */
-  OpenImage(image_info,image,WriteBinaryType);
-  if (image->file == (FILE *) NULL)
+  status=OpenBlob(image_info,image,WriteBinaryType);
+  if (status == False)
     WriterExit(FileOpenWarning,"Unable to open file",image);
   TransformRGBImage(image,RGBColorspace);
   /*
@@ -575,9 +573,8 @@ Export unsigned int WriteXWDImage(const ImageInfo *image_info,Image *image)
   lsb_first=1;
   if (*(char *) &lsb_first)
     MSBFirstOrderLong((char *) &xwd_header,sizeof(xwd_header));
-  (void) fwrite((char *) &xwd_header,sz_XWDheader,1,image->file);
-  (void) fwrite((char *) image->filename,1,Extent(image->filename)+1,
-    image->file);
+  (void) WriteBlob(image,sz_XWDheader,(char *) &xwd_header);
+  (void) WriteBlob(image,Extent(image->filename)+1,(char *) image->filename);
   if (image->class == PseudoClass)
     {
       XColor
@@ -613,7 +610,7 @@ Export unsigned int WriteXWDImage(const ImageInfo *image_info,Image *image)
         color.green=colors[i].green;
         color.blue=colors[i].blue;
         color.flags=colors[i].flags;
-        (void) fwrite((char *) &color,sz_XWDColor,1,image->file);
+        (void) WriteBlob(image,sz_XWDColor,(char *) &color);
       }
       FreeMemory((char *) colors);
     }
@@ -638,19 +635,19 @@ Export unsigned int WriteXWDImage(const ImageInfo *image_info,Image *image)
     for (j=0; j <= ((int) p->length); j++)
     {
       if (image->class == PseudoClass)
-        WriteQuantum(p->index,q)
+        *q++=p->index;
       else
         {
-          WriteQuantum(p->red,q);
-          WriteQuantum(p->green,q);
-          WriteQuantum(p->blue,q);
+          *q++=DownScale(p->red);
+          *q++=DownScale(p->green);
+          *q++=DownScale(p->blue);
         }
       x++;
       if (x == (int) image->columns)
         {
           for (x=0; x < (int) scanline_pad; x++)
-            WriteQuantum(0,q);
-          (void) fwrite((char *) pixels,1,q-pixels,image->file);
+            *q++=0;
+          (void) WriteBlob(image,q-pixels,(char *) pixels);
           if (image->previous == (Image *) NULL)
             if (QuantumTick(y,image->rows))
               ProgressMonitor(SaveImageText,y,image->rows);
@@ -662,7 +659,7 @@ Export unsigned int WriteXWDImage(const ImageInfo *image_info,Image *image)
     p++;
   }
   FreeMemory((char *) pixels);
-  CloseImage(image);
+  CloseBlob(image);
   return(True);
 }
 #else
