@@ -1435,7 +1435,7 @@ int main(int argc,char **argv)
         for (p=image; p != (Image *) NULL; p=p->next)
           scene--;
         if (image_info.verbose)
-          DescribeImage(image,stderr,False);
+          DescribeImage(image,stdout,False);
         if ((format == (char *) NULL) && (status != False))
           if (Latin1Compare(image_info.filename,"-") != 0)
             {
