@@ -1174,7 +1174,7 @@ int main(int argc,char **argv)
   }
   (void) strcpy(montage_image->magick_filename,argv[argc-1]);
   if (image_info.verbose)
-    DescribeImage(montage_image,stderr,False);
+    DescribeImage(montage_image,stdout,False);
   DestroyDelegateInfo();
   Exit(status ? 0 : errno);
   return(False);
